##########################################################################
###### READING IN DATA WITH MISSING YEARS ################################
##########################################################################

indata <- read.table("hdpp_data_missing.excess.out",header=T,sep=",")
year <- indata[,1]
id <- indata[,2]
exinc <- indata[,3]
exinc[exinc==-99] <- NA
people <- as.factor(sort(unique(id)))
numpeople <- length(people)
NT <- length(exinc)

###########################################################################
###### CREATING FILLED IN MATRIX AND MATRIX OF DIFFERENCES ################
###########################################################################

diffmat <- matrix(NA,nrow=NT,ncol=4)
diffmat[1,] <- c(NA,NA,id[1],year[1])
for (a in 2:(NT-1)){
	curyear <- year[a]
	curid <- id[a]
	littlediff <- NA
	if (curid == id[a-1]){
		littlediff <- exinc[a]-exinc[a-1]
	}
	bigdiff <- NA		
	if (curid == id[a-1] & curid == id[a+1]){
		bigdiff <- exinc[a+1]-exinc[a-1]
	}
	diffmat[a,] <- c(bigdiff,littlediff,curid,curyear)
	print (a)
}
diffmat[NT,] <- c(NA,exinc[NT]-exinc[NT-1],id[NT],year[NT])


###########################################################################
###### CREATING A1 AND B1 MATRICES ########################################
###########################################################################


temp <- which(is.na(diffmat[,1]) | is.na(diffmat[,2]))    ## all rows where either differences are missing
Amat <- diffmat[-temp,]   ## matrix with both differences present
temp2 <- which(is.na(diffmat[,2]) & is.na(diffmat[,1])==F) ## all rows with just second entry missing
Bmat <- diffmat[temp2,]

completecaseN <- length(Amat[,1])
missingcaseN <- length(Bmat[,1])

Amatcol1sort <- sort(Amat[,1])
Amatcol1percentile <- quantile(Amatcol1sort,probs=seq(1,99,1)/100)   
Cvec <- unique(Amatcol1percentile)
numbins <- length(Cvec)

A1 <- cbind(Amat[,1:2],rep(NA,completecaseN),Amat[,3:4])
for (i in 1:completecaseN){
	curcase <- Amat[i,1]
	curbin <- NA
	temp <- which(curcase < Cvec)
	if (length(temp) > 0){
		curbin <- min(temp)
	}
	if (length(temp) == 0){
		curbin <- numbins
	}
	A1[i,3] <- curbin
	print(i)
}


B1 <- cbind(Bmat[,1:2],rep(NA,missingcaseN),Bmat[,3:4])
for (i in 1:missingcaseN){
	curcase <- Bmat[i,1]
	curbin <- NA
	temp <- which(curcase < Cvec)
	if (length(temp) > 0){
		curbin <- min(temp)
	}
	if (length(temp) == 0){
		curbin <- numbins
	}
	B1[i,3] <- curbin
	print(i)
}


###########################################################################
###### FILLING IN MISSING DIFF ############################################
###########################################################################

for (i in 1:missingcaseN){
	curbin <- B1[i,3]
	matchrows <- which(A1[,3] == curbin)
	samprow <- sample(matchrows,size=1)
	B1[i,2] <- A1[samprow,2]
	print(i)
}


###########################################################################
###### FILLING IN MISSING INC WITH MISSING DIFF ###########################
###########################################################################

filledin <- indata
filledin[filledin==-99] <- NA

for (i in 1:NT){
   if (is.na(filledin[i,3])){
   	  curyear <- filledin[i,1]
   	  curperson <- filledin[i,2] 
	  if (filledin[i-1,1] == filledin[i,1]-1 & filledin[i-1,2] == filledin[i,2]){
	   	 temp <- which(B1[,4]==curperson & B1[,5]==curyear)
   	 	 filledin[i,3] <- filledin[i-1,3]+B1[temp,2]
	  }
      print(i)
   }
}

out <- write.table(filledin,file="hdpp_data_fill.excess.out",sep=",",col.names=c("year","id","ex1"),row.names=F,quote=F)

