

%% Perfect Sorting Case

% Here I find the gamma values associated with each percentile value in
% logninvx. Mean and variance come from Sahm paper.
logninvx=(.01:.01:.99);
loginvx=[.000001,logninvx,.999]';
lognx=logninv(loginvx,1.05,sqrt(.76));  % note: these are parameters for distribution of gamma not 1/gamma
lognx=flipud(lognx);  % so big gamma on top (associated with small sig2)

% Here I compute the percentile values for sigma2, and append it at the
% bottom with approx. 0 and at the top with 1.
v=(1:1:99)';
u=round(v*length(sigma2)/100);
sig2pervec=sort(sigma2,'ascend');
sig2pervec=[.000001;sig2pervec(u);1]; % top and bottom are 0 and 100th percentile

% Here I match sigma2 percentile to gamma percentile and interpolate a
% hypothetical vector of sigma2 values using the imposed sigma2/gamma
% mapping.
spacing=.0001;
s2vec=(min(sigbinrange(:,1)):spacing:1)';   % fine grid of sigma2 values
s2gammamap=interp1(sig2pervec,lognx,s2vec); % matches fine sigma2 values to gamma values
                                            % matches small sigma2 to big gamma

% garea is the approx. area over each s2vec region (with height of inferred
% gamma). This is so I can approx. yc=y0+.5*int(from 0 to sigma2) gamma(sigma2)dgamma.
garea=spacing*s2gammamap;  % so garea is size of rectangle for that gamma/sig2 pair

% gammasum is the cumulative sum values of gamma(sigma2) from 0 to sigma2 - approximates the integral
gammasum=zeros(size(s2vec));
for i=1:length(s2vec)
    gammasum(i)=sum(garea(1:i));
end
    
% Here yc=yo+.5*int(from 0 to sigma2) is solved for:
yc=zeros(size(s2vec));
for i=1:length(s2vec)
    yc(i)=0+.5*gammasum(i);  % why not y_0=0?
end

% now exponentiate since yc is really ln of risk-return menu
yc=exp(yc);

% s2med is just the median value of sigma2
s2med=median(sort(sigma2,'ascend'));

% solving for gamma(median(sigma2)) for normalization
normperfsort=interp1(s2vec,yc,s2med);

% normalize so at median(sigma2) yc=0.
ycnorm1=yc-normperfsort;

psortgamma=interp1(s2vec,s2gammamap,sigma2);
halfgamsig=scalewts.*.5.*sigma2.*psortgamma;
meanpsort=mean(halfgamsig);

%% Risk Return Menu from Data

% s2bins holds the fraction of weighted observations in each sigma2 bin  
[s2bins,medsig2vals_new,counted]=s2tenbins(sigbinrange,sigma2,scalewts);

% solving for m: myfsigzero=f(sigma|gamma) and s2bins=f(sigma)
prem97=(myfsigzero./s2bins).^(1/mybetainv);
normdata97=interp1(medsig2vals_new.^2,prem97,s2med);
ycnorm2_97=prem97-normdata97;
bottomval=interp1(medsig2vals_new.^2,ycnorm2_97,min(s2vec),'linear','extrap');


% Plot figure
figure1 = figure('Color',[1 1 1]);
axes1 = axes('Parent',figure1);
xlim(axes1,[0.159 0.2])
box(axes1,'on');
hold(axes1,'all');
plot(sqrt(s2vec),ycnorm1,'LineWidth',2,'LineStyle','--','Color',[1 0 0]);
hold on
% Create plot
plot(medsig2vals_new,ycnorm2_97,'MarkerSize',24,'Marker','.','LineWidth',2,'Color',[0 0 1]);
plot([min(sqrt(s2vec));medsig2vals_new(1)],[bottomval;ycnorm2_97(1)],'LineWidth',2,'LineStyle','--','Color',[0 0 1]);
xlabel('\bf{Sigma}');
ylabel('\bf{Income Premium}');
hold off
print(figure1,'-dpdf','H:\Research\IncomeVolatility\WriteUp\QE_GoldCopy\Raw_Fig_PDFs\Figure_3_left.pdf')

figure2 = figure('Color',[1 1 1]);
axes2 = axes('Parent',figure2);
xlim(axes2,[0.2 1])
box(axes2,'on');
hold(axes2,'all');
plot(sqrt(s2vec),ycnorm1,'LineWidth',2,'LineStyle','--','Color',[1 0 0]);
hold on
% Create plot
plot(medsig2vals_new,ycnorm2_97,'MarkerSize',24,'Marker','.','LineWidth',2,'Color',[0 0 1]);
xlabel('\bf{Sigma}');
ylabel('\bf{Income Premium}');
hold off
print(figure2,'-dpdf','H:\Research\IncomeVolatility\WriteUp\QE_GoldCopy\Raw_Fig_PDFs\Figure_3_right.pdf')
