%% Setup for Structural Estimation
tic;
clear;
clc;
addpathpath=strcat('H:\Research\IncomeVolatility\Matlab\QE_GoldCopy');
addpath(addpathpath);
cd(addpathpath);

%% Open matlabpool
if matlabpool('size')==0
    matlabpool open 4
else
    matlabpool close
    matlabpool open 5
end

%% Define covariate specification and whether bootstrapping 
bootstrap='yes'; % can be 'no' or 'yes'
cov_indicator='some_covariates'; % could be 'no_covariates', 'some_covariates' or 'all_covariates'
sigbin_method='approximate'; % can be 'approximate' or 'exact'
run display_method

%% Read in data
statadata=csvread('H:\Research\IncomeVolatility\Stata\outputdata\outputdata_GoldCopy\cleandata_final.csv',1,0);
id=statadata(:,1);
sigma2=statadata(:,2);
income=statadata(:,3);
risktolerance=statadata(:,4);
weights=statadata(:,5);
covmat=statadata(:,6:16);   % 6:16 are: age, race2=black, race3=other, edym, and occ dummies 1,2,4,5,6,7,8 (occ 10 is base case, occ 3 and 9 have no obs.)
trial_sigma2s=statadata(:,17:end);
numtrials=length(trial_sigma2s(1,:));

%% Define covariate matrix if restricted
if strcmp(cov_indicator,'no_covariates')==1
    covmat=zeros(size(covmat(:,1))); % coded so lnlhood_structural.m can run without alterations; could code as matrix of zeros of any size
   %covmat=zeros(size(covmat)); only here to verify we get same estimates for no_covariates case regardless of size of zeros matrix
elseif strcmp(cov_indicator,'some_covariates')==1
    covmat=statadata(:,6:9);
end
    
%% Here I generate the 10 sigma2 bin ranges        
[sigbinrange]=sigbincalc(sigbin_method,sigma2,weights);
        
%% Estimate Model Parameters and Standard Errors

% Run Bootstrap 100 sample structural estimates (standard errors implicit)
if strcmp(bootstrap,'yes')==1
    betainvmat=zeros(numtrials,1);
    fsig0mat=zeros(10,numtrials);
    thetamat=zeros(length(covmat(1,:)),numtrials);
    counted=zeros(numtrials,1);
    counted1=zeros(numtrials,1);
    
    for i=1:numtrials
        display(['at trial number', num2str(i)])
        boot_sigbinrange=sigbincalc('exact',trial_sigma2s(:,i),weights);
        sqrt(boot_sigbinrange)
        [betainvmat(i,1),fsig0mat(:,i),thetamat(:,i),a1,b1,c1,d1,e1,f1,g1,counted(i),counted1(i)]=...
            Bootstrap_Estimation_with_Covariates(id,trial_sigma2s(:,i),income,risktolerance,weights,covmat,boot_sigbinrange,cov_indicator,bootstrap);
    end
    sorted_betas=sort(1./betainvmat);
    sorted_fsig0s=[sort(fsig0mat(1,:));sort(fsig0mat(2,:));sort(fsig0mat(3,:));sort(fsig0mat(4,:));...
        sort(fsig0mat(5,:));sort(fsig0mat(6,:));sort(fsig0mat(7,:));sort(fsig0mat(8,:));sort(fsig0mat(9,:));...
        sort(fsig0mat(10,:))];
    boot_fsig0=sorted_fsig0s(:,50);
    display('bootstrapped: beta estimate, beta lower bound, beta upper bound')
    fprintf('%10.4f %10.4f %10.4f\n',[sorted_betas(50) sorted_betas(5) sorted_betas(96)])
    display('bootstrapped f(sigma|gamma=0) estimate')
    fprintf('%10.4f\n',boot_fsig0)
    toc1=toc;

% Or run estimates from Jensen-Shore volatility values without bootstrapping
elseif strcmp(bootstrap,'no')==1
    [mybetainv,myfsigzero,mytheta,logvzeromat,medsig2vals,gdist,fgonbin,riskavbin,databig,covmat]...
        =Structural_Estimation_with_Covariates(id,sigma2,risktolerance,weights,covmat,sigbinrange);
    display('.')
    display('beta estimate')
    fprintf('%10.4f\n',1/mybetainv)
    display('f(sigma|gamma=0) estimate')
    fprintf('%10.4f\n',myfsigzero(1:10,:))
    if strcmp(cov_indicator,'no_covariates')==0
        display('theta (covariate coefficient estimate) note: not meaningful if no_covariates')
        fprintf('%10.4f\n',mytheta)
    end
     
    % Find upper/lower bounds on betainv such that abs(chi2cdf(2*(lnlikelihood-lnlbase),1)-threshold)=0
    options=optimset('MaxFunEvals',1e+13,'maxiter',250000,'TolFun',1e-8);
    lnlbase=lnlhood_structural(logvzeromat,mybetainv,myfsigzero,mytheta',medsig2vals,gdist,fgonbin,riskavbin,databig,covmat);
    guess1=.25;
    guess2=2.5;
    display('searching for betainvhat1')
    [betainvhat1]=findbestbetainv_structural(guess1,myfsigzero,mytheta',lnlbase,.95,logvzeromat,medsig2vals,gdist,fgonbin,riskavbin,databig,covmat);
    display('searching for betainvhat2')
    [betainvhat2]=findbestbetainv_structural(guess2,myfsigzero,mytheta',lnlbase,.95,logvzeromat,medsig2vals,gdist,fgonbin,riskavbin,databig,covmat);
    display('beta estimate, beta lower bound, beta upper bound')
    fprintf('%10.4f %10.4f %10.4f\n',[1/mybetainv 1/betainvhat1 1/betainvhat2])

    
    % Find bounds on each component of fsigzero   
    threshold=.975;
    fsig0boundsdown=zeros(length(myfsigzero),1);
    fsig0boundsup=zeros(length(myfsigzero),1);
    parfor i=1:length(myfsigzero)
        display('searching for fsig0bound of')
        i
        fsig0boundsdown(i,1)=findbestonefixpos_structural(mybetainv,myfsigzero,mytheta,i,logvzeromat,medsig2vals,gdist,threshold,lnlbase,myfsigzero(i),-1,fgonbin,riskavbin,databig,covmat,options);
        fsig0boundsup(i,1)=findbestonefixpos_structural(mybetainv,myfsigzero,mytheta,i,logvzeromat,medsig2vals,gdist,threshold,lnlbase,myfsigzero(i),1,fgonbin,riskavbin,databig,covmat,options);
    end
    fsig0bounds=[fsig0boundsdown(:,1),fsig0boundsup(:,1)];
    %toc2=toc-toc1;
end


%% Produce the figures found in the paper
if strcmp(cov_indicator,'no_covariates')==1 && strcmp(bootstrap,'no')==1
    run Figures
end


