function [sigbinrange]=sigbincalc(sigbin_method,sigma2,weights)

if strcmp(sigbin_method,'approximate')==1
    % This method produces the approximate bin points, based on rought
    % estimates of the quantiles
    sigbinrange=[.16,  .164;
                 .164, .17;
                 .17,  .173;
                 .173, .1775;
                 .1775,.18;
                 .18,  .182;
                 .182, .217;
                 .217, .345;
                 .345,.999999999;
            .999999999,1.000].^2;

elseif strcmp(sigbin_method,'exact')==1
    % This calculation of sigbinrange uses exact quantiles (except for the 99th
    % percentile, which we deem by fiat sigma^2=1). This corresponds to the
    % method used in the bootstrapping estimation, but we follow the rough
    % quantiles computed above for the main estimation in the paper:
    sorted_sigma2s=sortrows([sqrt(sigma2),weights],1);    
    percentile_s2=zeros(length(sigma2),1);
    for j=1:length(sigma2)
        percentile_s2(j)=sum(sorted_sigma2s(1:j,2))/sum(weights);
    end
    sigbinrange=[.999*min(sorted_sigma2s(:,1)),1.00001*sorted_sigma2s(sum((percentile_s2<.01))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.01))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.05))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.05))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.1))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.1))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.3))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.3))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.5))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.5))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.7))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.7))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.9))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.9))+1,1),1.00001*sorted_sigma2s(sum((percentile_s2<.95))+1,1);
             1.00001*sorted_sigma2s(sum((percentile_s2<.95))+1,1),.999999999;
            .999999999,1.000].^2;
end