*This file creates cleandata2, which is used in the Matlab structural estimation,
*along with other data sets.

clear

****** Load volatility data which is year, id, sigma2 *********
clear
insheet using "$startdir/$inputdata/$volvals"
rename v1 id
rename v2 year
rename v3 sigma2

sort year id
save "$startdir/$outputdata\temp2.dta", replace


clear
use "$startdir/$outputdata\finalclean_malelaborlabor.dta"
sort year id
drop weight
rename weightnew weight
save "$startdir/$outputdata\temp5", replace

clear
use "$startdir/$outputdata\temp2.dta"
merge year id using "$startdir/$outputdata\temp5.dta"
drop _merge*
sort id year
gen income=reallab
*keep if weight!=0

save "$startdir/$outputdata\mprem_final", replace

erase "$startdir/$outputdata\temp2.dta"
erase "$startdir/$outputdata\temp5.dta"

clear
use "$startdir/$outputdata\mprem_final"
merge id year using "$startdir/$outputdata\MP_data.dta"
drop _merge*
sort id year



************* Generate Race Dummies (as of 1997) ***************************************
*race2=black, race3=other, so white is baseline case
gen race297=0
gen race397=0
replace race297=1 if race==2 & year==1997
replace race397=1 if race==3 & year==1997
egen maxrace2=max(race297), by (id)
egen maxrace3=max(race397), by (id)
gen race2=maxrace2
gen race3=maxrace3

******** Generate risk aversion variable and risk aversion bin dummies ********************
*first I fill in risk aversion values into years with missing data:
egen maxrisktol=max(risktolerance1), by(id)
replace risktolerance1=maxrisktol

*smallest risk aversion is base for dummy variables
gen riskavbin2=0
gen riskavbin3=0
gen riskavbin4=0
replace riskavbin2=1 if risktolerance1>.29 & risktolerance1<.37
replace riskavbin3=1 if risktolerance1>.26 & risktolerance1<.29
replace riskavbin4=1 if risktolerance1<.16

gen riskavbin=0
replace riskavbin=1 if risktolerance1>.56
replace riskavbin=2 if risktolerance1>.29 & risktolerance1<.37
replace riskavbin=3 if risktolerance1>.26 & risktolerance1<.29
replace riskavbin=4 if risktolerance1<.16


*Values of gamma come from matlab code: ln_gammainv_dist.m (on Feb. 6th 2013)
*riskav is E[gamma|bin]
gen riskav=(1-riskavbin2-riskavbin3-riskavbin4)*2.4242+riskavbin2*3.6856+riskavbin3*4.5124+riskavbin4*6.9675

*Added this line below since some risk tolerance values are missing
replace riskav=(.) if missing(risktolerance1)


******** Generate risk tolerance (1/gamma) variable ***************************
*Values of gamma come from matlab code: ln_gammainv_dist.m (on Feb. 6th 2013)
gen risktol=(1-riskavbin2-riskavbin3-riskavbin4)*.7512+riskavbin2*.4599+riskavbin3*.3757+riskavbin4*.2573


********* Generate ln(avg_income) where avg. is over 1991-1996 ***************************** 
gen Ytemp=.
replace Ytemp=reallab if year<=1996 & year>=1991
by id: egen avgY=mean(Ytemp)
gen lnavgY=ln(avgY)


******** Generate functions of sigma^2 *******************************
gen sig2sq=sigma2*sigma2
gen lnsig2=ln(sigma2)

gen sigma2_riskav=.5*sigma2*riskav

gen sig2temp=.
replace sig2temp=sigma2 if year<=1996 & year>=1991
by id: egen avgsig2=mean(sig2temp)

* Top code vol values at 1
replace avgsig2=1 if avgsig2>=1

gen avgsig2_riskav=.5*avgsig2*riskav
gen avgsig2sq=avgsig2*avgsig2
gen lnavgsig2=ln(avgsig2)


**** Setup Meghir-Pistaferri Moments **************************
gen mptemp=.
replace mptemp=mp if year<=1995 & year>=1991
egen avgmp=mean(mptemp), by(id)
gen avgmppresenttemp=1 if avgmp!=.
egen avgmppresent=max(avgmppresenttemp), by(id)
replace avgmp=1 if avgmp>=1
replace avgmp=-1 if avgmp<=-1


******** Generate functions of MP moments *******************************
gen mpsq=mp*mp
gen mp_riskav=.5*mp*riskav
gen avgmp_riskav=.5*avgmp*riskav
gen avgmpsq=avgmp*avgmp


********* Generate Occupation Dummies ***********************************
* Note: socc variable is coded as 1-10, but labeled as job description

gen occ91temp=.
replace occ91temp=socc if year==1991
*this next line just fills in occ91 in non-1991 years
by id: egen occ91=max(occ91temp)
replace occ91=10 if occ91==.

* occ91==10 is omitted occupation category
gen occdummy1=0
gen occdummy2=0
gen occdummy3=0
gen occdummy4=0
gen occdummy5=0
gen occdummy6=0
gen occdummy7=0
gen occdummy8=0
gen occdummy9=0
replace occdummy1=1 if occ91==1
replace occdummy2=1 if occ91==2
replace occdummy3=1 if occ91==3
replace occdummy4=1 if occ91==4
replace occdummy5=1 if occ91==5
replace occdummy6=1 if occ91==6
replace occdummy7=1 if occ91==7
replace occdummy8=1 if occ91==8
replace occdummy9=1 if occ91==9

gen ra_occdummy1=riskav*occdummy1
gen ra_occdummy2=riskav*occdummy2
gen ra_occdummy3=riskav*occdummy3
gen ra_occdummy4=riskav*occdummy4
gen ra_occdummy5=riskav*occdummy5
gen ra_occdummy6=riskav*occdummy6
gen ra_occdummy7=riskav*occdummy7
gen ra_occdummy8=riskav*occdummy8
gen ra_occdummy9=riskav*occdummy9


********** Other Interaction Vars with Sigma2 *******************************************
gen edym_avgsig2=edym*avgsig2
gen age_avgsig2=age*avgsig2


****** Generate Year Dummies ****************************************
gen dummy91=0
gen dummy92=0
gen dummy93=0
gen dummy94=0
gen dummy95=0
gen dummy96=0

replace dummy91=1 if year==1991
replace dummy92=1 if year==1992
replace dummy93=1 if year==1993
replace dummy94=1 if year==1994
replace dummy95=1 if year==1995
replace dummy96=1 if year==1996


******* Ensure both income and sigma2 present in all years 1991-1996 ****************************

gen inc_sig_1=0
gen inc_sig_2=0
gen inc_sig_3=0
gen inc_sig_4=0
gen inc_sig_5=0
gen inc_sig_6=0
replace inc_sig_1=1 if year==1991 & sigma2!=. & income!=.
replace inc_sig_2=1 if year==1992 & sigma2!=. & income!=.
replace inc_sig_3=1 if year==1993 & sigma2!=. & income!=.
replace inc_sig_4=1 if year==1994 & sigma2!=. & income!=.
replace inc_sig_5=1 if year==1995 & sigma2!=. & income!=.
replace inc_sig_6=1 if year==1996 & sigma2!=. & income!=.

gen inc_sig_tot=inc_sig_1+inc_sig_2+inc_sig_3+inc_sig_4+inc_sig_5+inc_sig_6
by id: egen inc_sig_all=sum(inc_sig_tot)


*********** Generate Sample 2 ****************************
gen insample2=1
replace insample2=0 if year!=1996 | risktolerance1==.
replace insample2=0 if weight==0 & year==1996
replace insample2=0 if inc_sig_all!=6


************* Save Data ***********************************
sort id year
order id year avgsig2 income risktolerance1 weight age race2 race3 edym occdummy1 occdummy2 occdummy4 occdummy5 occdummy6 occdummy7 occdummy8 edym_avgsig2 age_avgsig2 numfamunit havebaby numbaby haveskid numskid haveokid numokid
save "$startdir/$outputdata\bigdatatemp", replace

clear
use "$startdir/$outputdata\bigdatatemp", replace
merge id year using "$startdir/$outputdata\hdpp_data_missing.dta"
keep if _merge==3
drop _merge

save "$startdir/$outputdata\bigdata", replace
erase "$startdir/$outputdata\bigdatatemp.dta"

clear
use "$startdir/$outputdata\bigdata.dta"
keep if insample2==1
keep if ex1!=.
sort id
save "$startdir/$outputdata\cleandata2", replace

clear
use "$startdir/$outputdata\cleandata2.dta"
keep id
save "$startdir/$outputdata\id_list", replace

quietly do "$startdir\$dofiles\100sample_vol_analysis.do"

clear
use "$startdir/$outputdata\cleandata2.dta"
merge id using "$startdir/$outputdata\100sample_vol_id.dta"
order id year avgsig2 income risktolerance1 weight age race2 race3 edym occdummy1 occdummy2 occdummy4 occdummy5 occdummy6 occdummy7 occdummy8 trial_mean*
save "$startdir/$outputdata\cleandata_final", replace
outsheet id avgsig2 income risktolerance1 weight age race2 race3 edym occdummy1 occdummy2 occdummy4 occdummy5 occdummy6 occdummy7 occdummy8 trial* using "$startdir/$outputdata\cleandata_final.csv", comma replace

