/*This do-file merges the family income information post 1995 with the individual data so that we can identify exactly who each person is.*/

#delimit;
clear;
set memory 600m;

use "$startdir\$outputdata\coupleind.dta";
sort year intnum;
save, replace;

use "$startdir\$outputdata\fam.dta";
sort year intnum;

merge year intnum using "$startdir\$outputdata\coupleind.dta";

*note that much of the individual data doesn't match, as only the post 93 stuff is in both data sets;
drop if _merge==1; /*we only want data where we have both individual and supplemental family data.*/
                        /*this gives us 94-01, and we will get 68-93 data in buildext4b*/;
save "$startdir\$outputdata\temp.dta", replace;

sort year intnum;
save, replace;


keep if _merge==3;
drop _merge;

*this variable is generated automatically, but is irrevelant to the data set.;

****RELABELLING****;
*common across data sets, used for merging;
label variable year "year";
label variable intnum "family current interview number";

*family-level variables from fam.dta family data;
drop famsize;
*famsize is the same value as numfamunit;

*standardize consumption;
replace con1=. if con1>9997;
replace con1=con1*52 if year>1993;
label variable con1 "food expenditures at home";

replace con2=. if con2>9997;
replace con2=con2*52 if year>1993;
label variable con2 "money spent eating out";

label variable inc1 "transfers in from relatives";

label variable inc2 "total family income";
replace inc2=inc2supp if year>=1994 & year<=2005;
replace inc2=1 if inc2<=0 & inc2!=.; /*94-05 values can be negative without this*/

label variable inc3 "transfers out to relatives";
label variable HWtrans "transfer income to HD & WF";
label variable state "state of family residence";
label variable famcomp "composition of family";
label variable numfamunit "total family size";
label variable cntylabor "whether the county has a surplus or shortage of unskilled male labor";
label variable cntywage "typical wage for an unskilled male worker in the county";
label variable cntyunemp "county unemployment rate";
label variable numadults "number of adults (over 18) in family";
label variable numkids "number of children (under 18) in family";

replace marital=marital2 if marital==.;
label variable marital "head's marital status";
        label define maritallbl 1 "married";
        label define maritallbl 2 "single", add;
        label define maritallbl 3 "widowed", add;
        label define maritallbl 4 "divorced", add;
        label define maritallbl 5 "separated", add;
        label define maritallbl 8 "married, spouse absent", add;
        label define maritallbl 9 "n.a.", add;
        label values marital maritallbl;
        label values marital2 maritallbl;


*individual-level variables about HD/WF from fam.dta and faminc.dta family data;
/*Note: we remove all information about wives from the family data when the individual data ;
        *says that there is no wife.  Sometimes, people are listed with relhead=7 (other in-law)
        *while they claim to be married in the family data; */
***Note: inclusion of farm and business income later on is a recent change!!***;
rename Hlaborinc HDlabor;
replace HDlabor=HDearn+HDbusi if year>=1994 & year<=2005;
replace HDlabor=HDearn if year>=1994 & year<=2005 & HDbusi==.;
replace HDlabor=HDbusi if year>=1994 & year<=2005 & HDearn==.;
label variable HDlabor "head income from labor";

rename Wlaborinc WFlabor;
replace WFlabor=WFearn+WFbusi if year>=1994 & year<=2005;

replace WFlabor=WFearn if year>=1994 & year<=2005 & WFbusi==.;
replace WFlabor=WFbusi if year>=1994 & year<=2005 & WFearn==.;
replace WFlabor=. if wifepresent==0;
label variable WFlabor "wife income from labor";




rename hemploy HDempstat;
rename wemploy WFempstat;
label variable HDempstat "head's current employment status";
label variable WFempstat "wife's current employment status";
        label define empstatlbl 1 "working or temp laid off";
        label define empstatlbl 2 "unemployed", add;
        label define empstatlbl 3 "retired/disabled", add;
        label define empstatlbl 4 "housewife", add;
        label define empstatlbl 5 "student", add;
        label define empstatlbl 6 "other", add;
        label define empstatlbl 0 "missing", add;
recode HDempstat (1=1)   (2=2) (3=3)   (4=4) (5=5) (6=6) (missing=0)    if year>=1968 & year<=1975;
recode HDempstat (1/2=1) (3=2) (4/5=3) (6=4) (7=5) (8=6) (missing=0)    if year>=1976 & year<=1993;
recode HDempstat (1/2=1) (3=2) (4/5=3) (6=4) (7=5) (8=6) (missing=0)    if year>=1994 & year<=2001;
recode HDempstat (9=0) (98=0) (99=0)                                    if year>=1994 & year<=2001;
recode WFempstat (1=1)   (2=2) (3=3)   (4=4) (5=5) (6=6) (missing=0)    if year>=1968 & year<=1975;
recode WFempstat (1/2=1) (3=2) (4/5=3) (6=4) (7=5) (8=6) (missing=0)    if year>=1976 & year<=1993;
recode WFempstat (1/2=1) (3=2) (4/5=3) (6=4) (7=5) (8=6) (missing=0)    if year>=1994 & year<=2001;
recode WFempstat (9=0) (98=0) (99=0) (35=0)                                   ;
label values HDempstat empstatlbl;
label values WFempstat empstatlbl;

rename Hworkhrs HDworkhrs;
rename Wworkhrs WFworkhrs; replace WFworkhrs=. if wifepresent==0;

label variable HDworkhrs "head's hours spent working";
label variable WFworkhrs "wife's hours spent working";


rename race HDrace;
        recode HDrace (3/9=3);
        recode HDrace (.=0);
        label define racelbl 1 "white";
        label define racelbl 2 "black", add;
        label define racelbl 3 "other", add;
        label define racelbl 0 "missing", add;
        label values HDrace racelbl;
        label variable HDrace "race of head";

*occupation;
replace Hoccupation=hdocc if Hoccupation==.& Hoccupation<999;
rename Hoccupation HDocc;
label variable HDocc "head's occupational category";

replace Woccupation=wfocc if Woccupation==.& Woccupation<999;
rename Woccupation WFocc;
replace WFocc=. if wifepresent==0;
label variable WFocc "wife's occupational category";
*rename HWalimonyCS HWaliCS;
*label variable HWaliCS "head and wife's alimony and child support received - changes from year to year - look at excel sheet";

*education;
gen HDed = Heducation;
label variable HDed "head's level of education";
gen WFed = Weducation;  /*note that since WFed is drawn from family files, it is possible to have a nonmissing WFed while wifepresent==0*/;
label variable WFed "wife's level of education";

*note that WFed is absent for a few years around 1969-71;
sort year;
*by year: tab HDed;
*by year: tab WFed;
list HDed WFed year intnum WFpno68 if HDID68==4 & HDpno68==1;
list HDed WFed year intnum WFpno68 if HDID68==40 & HDpno68==1;
list HDed WFed year intnum WFpno68 if HDID68==40 & HDpno68==3;
recode HDed (0=1) (1=2) (2=3) (3=4) (4/5=5) (6=6) (7=7) (8=8) (9=0) (missing=0)                 if year==1968 | year==1969 | year==1970 | year==1971 | year==1972 | year==1973 | year==1974 |year==1985 | year==1986 | year==1987 | year==1988 | year==1989 | year==1990 ;
recode HDed (0=1) (1/5=2) (6/8=3) (9/11=4) (12=5) (13/15=6) (16=7) (17=8) (99=0) (missing=0)    if year==1975 | year==1976 | year==1977 | year==1978 | year==1979 | year==1980 | year==1981 | year==1982 | year==1983 | year==1984 | year==1991 | year==1992 | year==1993 | year==1994 | year==1995 | year==1996 | year==1997 | year==1999 | year==2001 | year==2003 | year==2005;

*****note that 83 wife doesn't line up.;
recode WFed (0=1) (1=2) (2=3) (3=4) (4/5=5) (6=6) (7=7) (8=8) (9=0) (missing=0)                 if year==1968 | year==1972 | year==1973 | year==1974 | year==1983 | year==1985 | year==1986 | year==1987 | year==1988 | year==1989 | year==1990;
recode WFed (missing=0)                                                                         if year==1969 | year==1970 | year==1971;
recode WFed (0=0) (1/5=2) (6/8=3) (9/11=4) (12=5) (13/15=6) (16=7) (17=8) (99=0) (missing=0)    if year==1975 | year==1976 | year==1977 | year==1978| year==1979 | year==1980 | year==1981 | year==1982 | year==1984 | year==1991 | year==1992 | year==1993 | year==1994 | year==1995 | year==1996 | year==1997 | year==1999 | year==2001 | year==2003 | year==2005;


gen HDedy=Heducation;
gen WFedy=Weducation;
recode HDedy (0=0) (1=5) (2=8) (3=10) (4/5=12) (6=14) (7=16) (8=17) (9=0) (missing=0)           if year==1968 | year==1969 | year==1970 | year==1971 | year==1972 | year==1973 | year==1974 |year==1985 | year==1986 | year==1987 | year==1988 | year==1989 | year==1990 ;
recode HDedy (99=0) (missing=0)                                                                 if year==1975 | year==1976 | year==1977 | year==1978 | year==1979 | year==1980 | year==1981 | year==1982 | year==1983 | year==1984 | year==1991 | year==1992 | year==1993 | year==1994 | year==1995 | year==1996 | year==1997 | year==1999 | year==2001 | year==2003 | year==2005;

recode WFedy (0=0) (1=5) (2=8) (3=10) (4/5=12) (6=14) (7=16) (8=17) (9=0) (missing=0)           if year==1968 | year==1972 | year==1973 | year==1974 | year==1983 | year==1985 | year==1986 | year==1987 | year==1988 | year==1989 | year==1990;
recode WFedy (missing=0)                                                                        if year==1969 | year==1970 | year==1971;
recode WFedy (99=0) (missing=0)                                                                 if year==1975 | year==1976 | year==1977 | year==1978| year==1979 | year==1980 | year==1981 | year==1982 | year==1984 | year==1991 | year==1992 | year==1993 | year==1994 | year==1995 | year==1996 | year==1997 | year==1999 | year==2001 | year==2003 | year==2005;

label variable HDedy "head's years of school";
label variable WFedy "wife's years of school";


list HDed WFed year intnum WFpno68 if HDID68==4 & HDpno68==1;
list HDed WFed year intnum WFpno68 if HDID68==40 & HDpno68==1;
list HDed WFed year intnum WFpno68 if HDID68==40 & HDpno68==3;
*list HDed if year==1985 & intnum==257;
*by year: tab HDed;
*by year: tab WFed;
replace WFed=. if year==1993;
        label define edlbl 1 "none";
        label define edlbl 2 "elementary", add;
        label define edlbl 3 "jrhigh", add;
        label define edlbl 4 "hsdropout", add;
        label define edlbl 5 "hsgrad", add;
        label define edlbl 6 "somecoll", add;
        label define edlbl 7 "collgrad", add;
        label define edlbl 8 "advanced", add;
        label define edlbl 0 "missing", add;
        label values HDed edlbl;
        label values WFed edlbl;

gen HDfed=HDFEducation;
gen HDmed=HDMEducation;
gen WFfed=WFFEducation;
gen WFmed=WFMEducation;
label variable HDfed "head's father's level of education";
label variable HDmed "head's mother's level of education";
label variable WFfed "wife's father's level of education";
label variable WFmed "wife's mother's level of education";
recode HDfed (0=1) (1=2) (2=3) (3=4) (4/5=5) (6=6) (7=7) (8=8) (9=0) (missing=0);
recode HDmed (0=1) (1=2) (2=3) (3=4) (4/5=5) (6=6) (7=7) (8=8) (9=0) (missing=0);
recode WFfed (0=1) (1=2) (2=3) (3=4) (4/5=5) (6=6) (7=7) (8=8) (9=0) (missing=0);
recode WFmed (0=1) (1=2) (2=3) (3=4) (4/5=5) (6=6) (7=7) (8=8) (9=0) (missing=0);
label values HDfed edlbl;
label values HDmed edlbl;
label values WFfed edlbl;
label values WFmed edlbl;

rename HDFEducation HDfedy;
rename HDMEducation HDmedy;
rename WFFEducation WFfedy;
rename WFMEducation WFmedy;
label variable HDfedy "head's father's years of education";
label variable HDmedy "head's mother's years of education";
label variable WFfedy "wife's father's years of education";
label variable WFmedy "wife's mother's years of education";
recode HDfedy (0=0) (1=5) (2=8) (3=10) (4/5=12) (6=14) (7=16) (8=17) (9=0) (missing=0);
recode HDmedy (0=0) (1=5) (2=8) (3=10) (4/5=12) (6=14) (7=16) (8=17) (9=0) (missing=0);
recode WFfedy (0=0) (1=5) (2=8) (3=10) (4/5=12) (6=14) (7=16) (8=17) (9=0) (missing=0);
recode WFmedy (0=0) (1=5) (2=8) (3=10) (4/5=12) (6=14) (7=16) (8=17) (9=0) (missing=0);

*cleanup cntyunemprate;
recode cntyunemp (1=1) (2=2) (3=3) (4/5=4) (6/7=5) (9=9) if year>1974 & year<1981;
recode cntyunemp (0/1.9=1) (2/3.9=2) (4/5.9=3) (6/10=4) (10.1/98=5) (99=9) if year>1980;
label define cntyunemplbl 1 "<2%";
        label define cntyunemplbl 2 "2-3.9%", add;
        label define cntyunemplbl 3 "4-5.9%", add;
        label define cntyunemplbl 4 "6-10%", add;
        label define cntyunemplbl 5 ">10%", add;
        label define cntyunemplbl 9 "NA", add;
        label values cntyunemp cntyunemplbl;


replace wfwge=0          if wifepresent==0;
replace WFempstat=0      if wifepresent==0;
replace WFedy=0          if wifepresent==0;
replace WFfed=0          if wifepresent==0;
replace WFmed=0          if wifepresent==0;


drop agehead agewife;
*rename Hindustry HDind;
*label variable HDind "head's industry of occupation";
*rename Windustry WFind;  *replace WFind=. if wifepresent==0;
*label variable WFind "wife's industry of occupation";
rename splitoffind split;
label variable split "whether or not family is a splitoff family";
*rename OalimonyCS OaliCS;
*label variable OaliCS "alimony and child support received for family members other than head or wife";
*rename PaidaliCS PaliCS;
*label variable PaliCS "amount of alimony and child support paid out by head and wife";


*family-level variables built from individual data, no geocodes;
label variable wifepresent "wife present in ind data";
label variable male1 "males aged 0-1";
label variable male2 "males aged 2-6";
label variable male3 "males aged 7-15";
label variable male4 "males aged 15-20";
label variable male5 "males aged 20-25";
label variable male6 "males aged 25-30";
label variable male7 "males aged 30-40";
label variable male8 "males aged 40-50";
label variable male9 "males aged 50-60";
label variable male10 "males aged 60-70";
label variable male11 "males aged 70+";
label variable female1 "females aged 0-1";
label variable female2 "females aged 2-6";
label variable female3 "females aged 7-15";
label variable female4 "females aged 15-20";
label variable female5 "females aged 20-25";
label variable female6 "females aged 25-30";
label variable female7 "females aged 30-40";
label variable female8 "females aged 40-50";
label variable female9 "females aged 50-60";
label variable female10 "females aged 60-70";
label variable female11 "females aged 70+";


*individual-level variables about HD/WF from individual data, no geocodes;
label variable HDsex "sex of head";
label variable WFsex "sex of wife";
label variable HDage68 "age of head in 1968";
label variable WFage68 "age of wife in 1968";
*There are problems with the family data ages in 1971 and 1992.  We use individual data ages.  Except for these two years, ages are generally identical to agehead and agewife variables.  Sometimes, one of the two measures is missing.  Here, we try to get the right measure of age when we think one is clearly in error.;
*plus, not all observations are consistent.  To deal with this, we use yearborn, which is calculated in the individual data based on an average of all individual year observations;
drop HDage68 WFage68 ;
replace WFyearborn=-997 if WFyearborn==0;
replace WFagelt=year-WFyearborn if WFyearborn>1850 & WFyearborn<1986;
replace WFagelt=-999 if WFyearborn<=1850 | WFyearborn>=1986 | WFyearborn==.;

replace HDyearborn=-997 if HDyearborn==0;
replace HDagelt=year-HDyearborn if HDyearborn>1850 & HDyearborn<1986;
replace HDagelt=-999 if HDyearborn<=1850 | HDyearborn>=1986 | HDyearborn==.;


rename HDagelt HDage;
rename WFagelt WFage;
rename HDindweight HDweight;
rename WFindweight WFweight;
label variable HDyearborn "year head born, consistent";
label variable WFyearborn "year wife born, consistent";
label variable HDage "current age of head, consistent";
label variable WFage "current age of wife, consistent";
label variable HDweight "weight of head";
label variable WFweight "weight of wife";
label variable HDID68 "head's 68 id number";
label variable WFID68 "wife's 68 id number";
rename WFrelhead68 WFrel68;
label variable WFrel68 "wife's relationship to head in 68";
rename HDrelhead68 HDrel68;
label variable HDrel68 "head's relationship to head in 68";
label variable HDpno68  "head's person number in 68";
label variable WFpno68 "wife's person number in 68";

*weights;
gen HDweightnew=HDweight;
replace HDweightnew=WFweight if HDweight==0 & WFweight>0 & WFweight!=.;
gen WFweightnew=WFweight;
replace WFweightnew=HDweight if WFweight==0 & HDweight>0 & HDweight!=.;
label variable HDweight "head weight, wfwt if hdwt=0";
label variable WFweight "wife weight, hdwt if wfwt=0";

label variable HDselfemployed "HD's self employed";
        label define selfemplbl 1 "work 4 other only";
        label define selfemplbl 2 "work 4 self & other", add;
        label define selfemplbl 3 "work 4 self only", add;
        label define selfemplbl 4 "wildcard", add;
        label define selfemplbl 8 "DK", add;
        label define selfemplbl 9 "NA", add;
        label define selfemplbl 0 "not in labor force", add;
        label values HDselfemployed selfemplbl;


label variable useseatbelts "Use seatbelts?";
        label define useseatbeltslbl 1 "always";
        label define useseatbeltslbl 3 "sometimes", add;
        label define useseatbeltslbl 5 "never", add;
        label define useseatbeltslbl 9 "NA", add;
        label define useseatbeltslbl 0 "inap.", add;
        label values useseatbelts useseatbeltslbl;

label variable haveseatbelts "Have seatbelts?";
        label define haveseatbeltslbl 1 "Yes";
        label define haveseatbeltslbl 5 "No", add;
        label define haveseatbeltslbl 9 "NA", add;
        label define haveseatbeltslbl 0 "inap.", add;
        label values haveseatbelts haveseatbeltslbl;



*standardized occupations;
gen HDsocc=.;

*1 digit, 68-75;
replace HDsocc=HDocc if year>=1968 & year<=1975;
replace HDsocc=10 if year>=1968 & year<=1975 & HDsocc==0;

*2 digit, 76-80;
replace HDsocc = 1 if     HDocc==10 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==11 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==12 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==13 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==14 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==15 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==16 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==17 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==18 & year>=1976 & year<=1980;
replace HDsocc = 1 if     HDocc==19 & year>=1976 & year<=1980;
replace HDsocc = 2 if     HDocc==20 & year>=1976 & year<=1980;
replace HDsocc = 2 if     HDocc==31 & year>=1976 & year<=1980;
replace HDsocc = 4 if     HDocc==40 & year>=1976 & year<=1980;
replace HDsocc = 4 if     HDocc==41 & year>=1976 & year<=1980;
replace HDsocc = 4 if     HDocc==45 & year>=1976 & year<=1980;
replace HDsocc = 5 if     HDocc==50 & year>=1976 & year<=1980;
replace HDsocc = 5 if     HDocc==51 & year>=1976 & year<=1980;
replace HDsocc = 5 if     HDocc==52 & year>=1976 & year<=1980;
replace HDsocc = 9 if     HDocc==55 & year>=1976 & year<=1980;
replace HDsocc = 6 if     HDocc==61 & year>=1976 & year<=1980;
replace HDsocc = 6 if     HDocc==62 & year>=1976 & year<=1980;
replace HDsocc = 7 if     HDocc==70 & year>=1976 & year<=1980;
replace HDsocc = 8 if     HDocc==71 & year>=1976 & year<=1980;
replace HDsocc = 4 if     HDocc==73 & year>=1976 & year<=1980;
replace HDsocc = 4 if     HDocc==75 & year>=1976 & year<=1980;
replace HDsocc = 8 if     HDocc==80 & year>=1976 & year<=1980;
replace HDsocc = 9 if     HDocc==99 & year>=1976 & year<=1980;
replace HDsocc = 10 if     HDocc==0  & year>=1976 & year<=1980;


*3 digit, 81-05;
replace HDsocc = 1 if     HDocc>= 001     & HDocc<=       195 & year>1980 & year<=2005;
replace HDsocc = 2 if     HDocc>= 201     & HDocc<=       245 & year>1980 & year<=2005;
replace HDsocc = 4 if     HDocc>= 260     & HDocc<=       285 & year>1980 & year<=2005;
replace HDsocc = 4 if     HDocc>= 301     & HDocc<=       395 & year>1980 & year<=2005;
replace HDsocc = 5 if     HDocc>= 401     & HDocc<=       600 & year>1980 & year<=2005;
replace HDsocc = 6 if     HDocc>= 601     & HDocc<=       695 & year>1980 & year<=2005;
replace HDsocc = 6 if     HDocc>= 701     & HDocc<=       715 & year>1980 & year<=2005;
replace HDsocc = 7 if     HDocc>= 740     & HDocc<=       785 & year>1980 & year<=2005;
replace HDsocc = 8 if     HDocc>= 801     & HDocc<=       802 & year>1980 & year<=2005;
replace HDsocc = 8 if     HDocc>= 821     & HDocc<=       824 & year>1980 & year<=2005;
replace HDsocc = 4 if     HDocc>= 901     & HDocc<=       965 & year>1980 & year<=2005;
replace HDsocc = 4 if     HDocc>= 980     & HDocc<=       984 & year>1980 & year<=2005;
replace HDsocc = 9 if     HDocc>= 999     & HDocc<=       999 & year>1980 & year<=2005;
replace HDsocc = 10 if     HDocc== 0       & HDocc<=         0 & year>1980 & year<=2005;

*1 digit;
gen WFsocc=.;
replace WFsocc=WFocc if year>=1968 & year<=1975;
replace WFsocc=10 if year>=1968 & year<=1975 & WFsocc==0;

*2 digit;
replace WFsocc = 1 if     WFocc==10 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==11 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==12 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==13 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==14 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==15 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==16 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==17 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==18 & year>=1976 & year<=1980;
replace WFsocc = 1 if     WFocc==19 & year>=1976 & year<=1980;
replace WFsocc = 2 if     WFocc==20 & year>=1976 & year<=1980;
replace WFsocc = 2 if     WFocc==31 & year>=1976 & year<=1980;
replace WFsocc = 4 if     WFocc==40 & year>=1976 & year<=1980;
replace WFsocc = 4 if     WFocc==41 & year>=1976 & year<=1980;
replace WFsocc = 4 if     WFocc==45 & year>=1976 & year<=1980;
replace WFsocc = 5 if     WFocc==50 & year>=1976 & year<=1980;
replace WFsocc = 5 if     WFocc==51 & year>=1976 & year<=1980;
replace WFsocc = 5 if     WFocc==52 & year>=1976 & year<=1980;
replace WFsocc = 9 if     WFocc==55 & year>=1976 & year<=1980;
replace WFsocc = 6 if     WFocc==61 & year>=1976 & year<=1980;
replace WFsocc = 6 if     WFocc==62 & year>=1976 & year<=1980;
replace WFsocc = 7 if     WFocc==70 & year>=1976 & year<=1980;
replace WFsocc = 8 if     WFocc==71 & year>=1976 & year<=1980;
replace WFsocc = 4 if     WFocc==73 & year>=1976 & year<=1980;
replace WFsocc = 4 if     WFocc==75 & year>=1976 & year<=1980;
replace WFsocc = 8 if     WFocc==80 & year>=1976 & year<=1980;
replace WFsocc = 9 if     WFocc==99 & year>=1976 & year<=1980;
replace WFsocc = 10 if     WFocc==0  & year>=1976 & year<=1980;


*3 digit;
replace WFsocc = 1 if     WFocc>= 001     & WFocc<=       195 & year>1980 & year<=2005;
replace WFsocc = 2 if     WFocc>= 201     & WFocc<=       245 & year>1980 & year<=2005;
replace WFsocc = 4 if     WFocc>= 260     & WFocc<=       285 & year>1980 & year<=2005;
replace WFsocc = 4 if     WFocc>= 301     & WFocc<=       395 & year>1980 & year<=2005;
replace WFsocc = 5 if     WFocc>= 401     & WFocc<=       600 & year>1980 & year<=2005;
replace WFsocc = 6 if     WFocc>= 601     & WFocc<=       695 & year>1980 & year<=2005;
replace WFsocc = 6 if     WFocc>= 701     & WFocc<=       715 & year>1980 & year<=2005;
replace WFsocc = 7 if     WFocc>= 740     & WFocc<=       785 & year>1980 & year<=2005;
replace WFsocc = 8 if     WFocc>= 801     & WFocc<=       802 & year>1980 & year<=2005;
replace WFsocc = 8 if     WFocc>= 821     & WFocc<=       824 & year>1980 & year<=2005;
replace WFsocc = 4 if     WFocc>= 901     & WFocc<=       965 & year>1980 & year<=2005;
replace WFsocc = 4 if     WFocc>= 980     & WFocc<=       984 & year>1980 & year<=2005;
replace WFsocc = 9 if     WFocc>= 999     & WFocc<=       999 & year>1980 & year<=2005;
replace WFsocc = 10 if     WFocc== 0       & WFocc<=         0 & year>1980 & year<=2005;


/*
1 digit
10 Not in labor force at all in 1967, retired (includes students and housewives who did no work last year and are not working). Permanently disabled or not in labor force and did no work last year.
1 Professional, technical and kindred workers
2 Managers, officials and proprietors
3 Self-employed businessmen
4 Clerical and sales workers
5 Craftsmen, foremen, and kindred workers
6 Operatives and kindred workers
7 Laborers and service workers, farm laborers
8 Farmers and farm managers
9 Miscellaneous (armed services, protective workers, unemployed last year but looking for work, N.A.)

2 digit
10 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Physicians (medical + osteopathic), Dentists (062,065)
11 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Other Medical and Paramedical: chiropractors, optometrists, pharmacists, veterinarians, nurses, therapists, healers, dieticians (except medical and dental technicians, see 16) (061,063,064,071-076)
12 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Accountants and Auditors (001)
13 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Teachers, Primary and Secondary Schools (including NA type) (141-145)
14 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Teachers, College; Social Scientists; Librarians; Archivists (032-036,091-096,102-140)
15 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Architects; Chemists; Engineers; Physical and Biological Scientists (002,006-023,042-054)
16 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Technicians: Airplane pilots and navigators, designers, draftsmen, foresters and conservationists, embalmers, photographers, radio operators, surveyors, technicians (medical, dental, testing, n.e.c.) (003-005,025,055,080-085,150-173,183,191)
17 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Public Advisors: Clergymen, editors and reporters, farm and home management advisors, personnel and labor relations workers, public relations persons, publicity workers, religious, social and welfare workers (024,026,056,086,090,100-101,184,192)
18 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Judges; Lawyers (030,031)
19 PROFESSIONAL, TECHNICAL AND KINDRED WORKERS (001-195): Professional, technical and kindred workers not listed above (174,175-182,185,190,193-195)
20 MANAGERS, OFFICIALS AND PROPRIETORS (EXCEPT FARM) (201-245): Not self-employed
31 MANAGERS, OFFICIALS AND PROPRIETORS (EXCEPT FARM) (201-245): Self-employed (unincorporated businesses)
40 CLERICAL AND KINDRED WORKERS: Secretaries, stenographers, typists (370-372,376,391)
41 CLERICAL AND KINDRED WORKERS: Other Clerical Workers: agents (n.e.c.) library assistants and attendants, bank tellers, cashiers, bill collectors, ticket, station and express agents, etc., receptionists (301-364,374-375,381,392-395)
45 SALES WORKERS: Retail store salesmen and sales clerks, newsboys, hucksters, peddlers, traveling salesmen, advertising agents and sales- men, insurance agents, brokers, and salesmen, etc. (260-280)
50 CRAFTSMEN, FOREMEN, AND KINDRED WORKERS: Foremen, n.e.c. (441)
51 CRAFTSMEN, FOREMEN, AND KINDRED WORKERS: Other craftsmen and kindred workers (401-440,442-580)
52 CRAFTSMEN, FOREMEN, AND KINDRED WORKERS: Government protective service workers; firemen, police, mar- shals, and constables (960-965)
55 MILITARY PERSONNEL: Members of armed forces
61 OPERATIVES AND KINDRED WORKERS: Transport equipment operatives (701-715)
62 OPERATIVES AND KINDRED WORKERS: Operatives, except transport (601-695)
70 LABORERS: Unskilled laborers--nonfarm (740-785)
71 LABORERS: Farm laborers and foremen (821-824)
73 SERVICE WORKERS: Private household workers (980-984)
75 SERVICE WORKERS: Other service workers: barbers, beauticians, manicurists, bartenders, boarding and lodging housekeepers, counter and fountain workers, housekeepers and stewards, waiters, cooks, midwives, practical nurses, babysitters, attendants in physicians' and dentists' offices (901-965 except 960-965 when working for local, state, or federal government)
80 FARMERS AND FARM MANAGERS: Farmers (owners and tenants) and managers (except code 71) (801-802)
99 NA; DK
0 Inap.; unemployed; retired, permanently disabled, housewife, student; V7094=3-8

3 digit codes:
1 - 195 Professional, Technical, and Kindred Workers       1
201 - 245 Managers and Administrators, except Farm         2
260 - 285 Sales Workers                                    4
301 - 395 Clerical and Kindred Workers                     4
401 - 600 Craftsman and Kindred Workers                    5
601 - 695 Operatives, except Transport                     6
701 - 715 Transport Equipment Operatives                   6
740 - 785 Laborers, except Farm                            7
801 - 802 Farmers and Farm Managers                        8
821 - 824 Farm Laborers and Farm Foremen                   8
901 - 965 Service Workers, except Private Household        4
980 - 984 Private Household Workers                        4
999 NA; DK                                                 9
0 Inap.: not working for money now (V20695=5)              10
*/;

label define occlbl 1 "Professional, technical and kindred workers";
label define occlbl 2 "Managers, officials and proprietors "   ,add;
label define occlbl 3 "Self-employed businessmen"              ,add;
label define occlbl 4 "Clerical and sales workers"             ,add;
label define occlbl 5 "Craftsmen, foremen, and kindred workers",add;
label define occlbl 6 "Operatives and kindred workers"         ,add;
label define occlbl 7 "Laborers and service workers, farm laborers",add;
label define occlbl 8 "Farmers and farm managers"              ,add;
label define occlbl 9 "Miscellaneous"                          ,add;
label define occlbl 10 "Inap.; no father; dead; no job; etc"    ,add;

replace HDfocc=10 if HDfocc==0;
label values HDfocc occlbl;
label values HDsocc occlbl;
label variable HDsocc "head's standardized 1-digit occ";
label variable HDfocc "head's father's 1-digit occ";


*Source: http://www.epi.org/issueguides/minwage/table4.pdf;
gen minwage=.;
replace minwage=    1.60           if year==   1968                 ;
replace minwage=    1.60           if year==   1969                 ;
replace minwage=    1.60           if year==   1970                 ;
replace minwage=    1.60           if year==   1971                 ;
replace minwage=    1.60           if year==   1972                 ;
replace minwage=    1.60           if year==   1973                 ;
replace minwage=    2.00           if year==   1974                 ;
replace minwage=    2.10           if year==   1975                 ;
replace minwage=    2.30           if year==   1976                 ;
replace minwage=    2.30           if year==   1977                 ;
replace minwage=    2.65           if year==   1978                 ;
replace minwage=    2.90           if year==   1979                 ;
replace minwage=    3.10           if year==   1980                 ;
replace minwage=    3.35           if year==   1981                 ;
replace minwage=    3.35           if year==   1982                 ;
replace minwage=    3.35           if year==   1983                 ;
replace minwage=    3.35           if year==   1984                 ;
replace minwage=    3.35           if year==   1985                 ;
replace minwage=    3.35           if year==   1986                 ;
replace minwage=    3.35           if year==   1987                 ;
replace minwage=    3.35           if year==   1988                 ;
replace minwage=    3.35           if year==   1989                 ;
replace minwage=    3.80           if year==   1990                 ;
replace minwage=    4.25           if year==   1991                 ;
replace minwage=    4.25           if year==   1992                 ;
replace minwage=    4.25           if year==   1993                 ;
replace minwage=    4.25           if year==   1994                 ;
replace minwage=    4.25           if year==   1995                 ;
replace minwage=    4.75           if year==   1996                 ;
replace minwage=    5.15           if year==   1997                 ;
replace minwage=    5.15           if year==   1998                 ;
replace minwage=    5.15           if year==   1999                 ;
replace minwage=    5.15           if year==   2000                 ;
replace minwage=    5.15           if year==   2001                 ;
replace minwage=    5.15           if year==   2002                 ;
replace minwage=    5.15           if year==   2003                 ;
replace minwage=    5.15           if year==   2004                 ;
replace minwage=    5.15           if year==   2005                 ;
label variable minwage "minimum wage";

*source: ftp://ftp.bls.gov/pub/special.requests/cpi/cpiai.txt;
gen cpi=.;
replace cpi=   34.8             if year==   1968                 ;
replace cpi=   36.7             if year==   1969                 ;
replace cpi=   38.8             if year==   1970                 ;
replace cpi=   40.5             if year==   1971                 ;
replace cpi=   41.8             if year==   1972                 ;
replace cpi=   44.4             if year==   1973                 ;
replace cpi=   49.3             if year==   1974                 ;
replace cpi=   53.8             if year==   1975                 ;
replace cpi=   56.9             if year==   1976                 ;
replace cpi=   60.6             if year==   1977                 ;
replace cpi=   65.2             if year==   1978                 ;
replace cpi=   72.6             if year==   1979                 ;
replace cpi=   82.4             if year==   1980                 ;
replace cpi=   90.9             if year==   1981                 ;
replace cpi=   96.5             if year==   1982                 ;
replace cpi=   99.6             if year==   1983                 ;
replace cpi=  103.9             if year==   1984                 ;
replace cpi=  107.6             if year==   1985                 ;
replace cpi=  109.6             if year==   1986                 ;
replace cpi=  113.6             if year==   1987                 ;
replace cpi=  118.3             if year==   1988                 ;
replace cpi=  124.0             if year==   1989                 ;
replace cpi=  130.7             if year==   1990                 ;
replace cpi=  136.2             if year==   1991                 ;
replace cpi=  140.3             if year==   1992                 ;
replace cpi=  144.5             if year==   1993                 ;
replace cpi=  148.2             if year==   1994                 ;
replace cpi=  152.4             if year==   1995                 ;
replace cpi=  156.9             if year==   1996                 ;
replace cpi=  160.5             if year==   1997                 ;
replace cpi=  163.0             if year==   1998                 ;
replace cpi=  166.6             if year==   1999                 ;
replace cpi=  172.2             if year==   2000                 ;
replace cpi=  177.1             if year==   2001                 ;
replace cpi=  179.9             if year==   2002                 ;
replace cpi=  184.0             if year==   2003                 ;
replace cpi=  188.9             if year==   2004                 ;
replace cpi=  195.3             if year==   2005                 ;
gen cpiratio=cpi/195.3;
label variable cpiratio "cpi/cpi2005";

order /*common variable*/year intnum
        /*fam vars from fam data*/ inc1 inc2 inc3 con1 con2 marital
        /*fam vars from ind data*/ wifepresent
        /*ind vars from fam data*/ HDlabor WFlabor HDworkhrs WFworkhrs HDed WFed HDocc WFocc HDrace
        /*ind vars from ind data*/ HDID68 WFID68 HDrel68 WFrel68 HDpno68 WFpno68 HDsex WFsex HDyearborn WFyearborn HDage WFage
;

*drop all family variables I haven't figured out what to do with yet.  These might be useful later;
drop cntylabor cntywage cntypsid famcompchange hholdrage hholdrsex hholdrelfamh
        hval hval2 hvalacc remmortprin remmortprinacc annmortpay annmortpayacc annproptax
        annproptaxacc annhomeins annrentpaid annrentpaidacc annfreehousval annfreehousacc
        annutil annutilacc govsubhtg hwhavetaxinc /*linc1*/ linc2 linc3 hwages hwagesacc hlinc1
         hlinc2 hlinc3 hlincacc wlinc1 wlincacc1 asinc1 asinc2 asinc3 asinc4 monrecvdrent
        hinc1 divintinc winc1 wincacc1 hwtaxinc hwtaxinc2 suppdnonfu blindexempt totexempt
        filestat hwrectransinc htranacc1 htran1 htran2 htran3 htran4 htran5 htran6 htran7
        htran8 wtran1 wtranacc1 wtran2 wtran3 wtran4 wtran5 wtran6 wtran7 wtran8 wtran9
        wtran10 hwtransnoafd* hwtran2 hage2 wage2 nonfuinfu marital2 /*dwelltype*/
        numrooms heatftyp1 heatftype2 recgovhtsub /*tenure mortinclptax havemort yearsmort
        havemort2*/ mortinclins rentfurn publhous govpayrenpart rentinclht whynotown inproj
        govpayrenall payutil movlastsp monmove whymove mightmove probmove whymigmove
        whymigmove2 hyearret hfarmer farmrcpt getlumpsum lumpsumamt
        inheramt itemtax /*networth*/ wracehisp wraceoth hnew hracehisp hrelig hwfedtax
        hwmtr fmoninc fmoninc2 region stfips cyfips fmonincacc nkids_1 nkids_2 nkids_3
        hnewyr wnewyr ;



drop
hdwks hdavg hdovt hdxtr wfwks wfavg wfovt wfxtr
hdilo hdils hdvac hdstr hdump hdolf
wfilo wfils wfvac wfstr wfump wfolf
Heducation Weducation cpi
haveseatbelts
useseatbelts
HDfocc
inc2supp
HDis1stmarr
HDageofmarr;


drop s5* s6* s7* con1 con2 state famcomp cntyunemp linc1 inc1 inc3 HWtrans dwelltype tenure mortinclptax havemort;
drop yearsmort havemort2 networth WhenMovedIn HDfed* HDmed* WFfed* WFmed*;
drop HDearn WFearn HDbusi WFbusi hdwge wfwge hdocc wfocc fips94 psid94 s3* up* fips* psid*;
drop split HDocc WFocc;

sort intnum year;
save temp, replace;
infix   intnum 1-4               risktolerance 5-9              risktolerance1 10-13 using "$startdir\$inputdata\rt\rt.dat", clear;
sort intnum;
save temp2, replace;
merge intnum using temp;
tab year, sum(_merge);
replace risktolerance=. if year!=1996;
replace risktolerance1=. if year!=1996;
sort HDID68 HDpno68;
egen HDrisktolerance= max(risktolerance), by(HDID68 HDpno68);
egen HDrisktolerance1=max(risktolerance1), by(HDID68 HDpno68);
egen WFrisktolerance= max(risktolerance), by(WFID68 WFpno68);
egen WFrisktolerance1=max(risktolerance1), by(WFID68 WFpno68);

label variable HDrisktolerance "1/CRRA, higher is more risk tol";
label variable HDrisktolerance1 "corrected risk tolerance";
label variable WFrisktolerance "1/CRRA, higher is more risk tol";
label variable WFrisktolerance1 "corrected risk tolerance";
drop risktolerance risktolerance1 _merge;

save "$startdir\$outputdata\final.dta", replace;
save "$startdir\$outputtables/$runname$date\final.dta", replace;

!erase temp.dta;
!erase temp2.dta;



*income of HD only;
keep if HDsex==1;
drop WF*;
renpfix HD;
save "$startdir\$outputdata\maleinc.dta", replace;
save "$startdir\$outputtables/$runname$date\maleinc.dta", replace;


*income of WF only;
use "$startdir\$outputdata\final.dta", clear;
keep if HDsex==2;
drop WF*;
renpfix HD;
save "$startdir\$outputdata\femaleinc1.dta", replace;

use "$startdir\$outputdata\final.dta", clear;
keep if wifepresent==1;
drop HD*;
renpfix WF;
save "$startdir\$outputdata\femaleinc2.dta", replace;
append using "$startdir\$outputdata\femaleinc1.dta";
save "$startdir\$outputdata\femaleinc.dta", replace;
erase "$startdir\$outputdata\femaleinc1.dta";
erase "$startdir\$outputdata\femaleinc2.dta";



