
/* build1 */
/* 8-5-05 */
/* Misha Dworsky wrote generating code originally, modified by Stephen Shore */
/*
Matches conceptual variables (variable names) with PSID variable numbers
year-by-year, then appends all years to create a single family-year dataset
with consistent variables across all years.

Replaces Steve's "build1.do" file as the first step in his cycle
of do-files for processing the PSID.  Body is cut-n-pasted from code
automatically generated by crosswalkguide.xls.  Raw data in .dta files
found in "$startdir/$inputdata",
appended family-year file sent to $startdir/outputdata.

Currently works for 1968-93.  Will be extended through 2003 when crosswalk
complete.

Means checked and crosswalk updated 3-22.
*/

#delimit ;
clear;
set memory 200m;
set more off;




/*****************************************/

/* BEGIN AUTOMATED CODE FROM build1merge.doc */

cd "$startdir/$inputdata";

use 68fam, clear;

capture gen year=1900+68;

/* Steve variables */

capture drop temp; gen temp = v3; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v93; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v114; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v30; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v37; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v163; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v262; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v81; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v82; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v115; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v117; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v118; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v47; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v53; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v74; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v75; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v197; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v243; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v246; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v313; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v181; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v116; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v398; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v412; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v413; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v414; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v94; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v117; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v119; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v5; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v7; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v8; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v9; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v6; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v7; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v10; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v11; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v12; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v13; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v14; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v15; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v251; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v252; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v253; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v85; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v264; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v86; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v320; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v255; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v263; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v76; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v234; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v82; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v81 - (v76 + v79); rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v80; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v90; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v257; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v258; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v259; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v81-v76-v79; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v368; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = v369; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v190; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v102; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v103; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v193; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v105; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v111; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v112; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v196; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v249; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v266; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v83; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v81; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v339; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v361; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v239; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v439; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v318; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = v101; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v198; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = v152; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = v153; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = v379; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = v247; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means68.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam68, replace;cd "$startdir/$inputdata";

use 69fam, clear;

capture gen year=1900+69;

/* Steve variables */

capture drop temp; gen temp = v442; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v537; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v547; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v493; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v500; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v506; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v713; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v529; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v530; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v549; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v1008; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v1011; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v465; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v475; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v514; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v516; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v640; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v609; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = .; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v794; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v801; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v894; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v550; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v538; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v542; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v1009; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v1010; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v544; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v449; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v824; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v450; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v451; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v452; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v453; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v454; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v822; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v455; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v456; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v457; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v458; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v460; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v461; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v699; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v700; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v701; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v515; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v716; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v980; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v823; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v703; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v715; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v518; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v830; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v530; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v525; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v523; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v526; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v705; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v706; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v707; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v833; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v526; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v525; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v1009; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = v1012; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v810; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v592; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v593; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v594; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v595; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v813; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v596; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v603; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v604; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v605; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v606; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v639; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v608; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v695; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v718; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v719; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v791; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v532; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v529; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v827; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v876; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v607; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = .; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v793; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v641; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = v585; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = v586; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means69.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam69, replace;cd "$startdir/$inputdata";

use 70fam, clear;

capture gen year=1900+70;

/* Steve variables */

capture drop temp; gen temp = v1102; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v1103; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v1114; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v1167; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v1175; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v1185; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v1216; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v1514; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v1228; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v1238; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v1239; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v1241; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v1138; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v1148; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v1196; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v1198; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v1279; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v1367; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = .; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v1485; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v1490; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v1591; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v1242; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v1104; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v1106; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v1109; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v1122; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v1511; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v1123; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v1124; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v1125; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v1126; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v1127; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v1509; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v1128; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v1129; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v1130; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v1131; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v1133; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v1134; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v1189; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v1190; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v1195; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v1191; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v1192; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v1193; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v1194; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v1197; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v1517; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v1199; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v1200; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v1201; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v1202; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v1203; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v1204; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v1206; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v1205; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v1518; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v1228; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v1209; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v1210; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v1211; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v1212; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v1213; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v1214; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v1217; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v1218; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v1219; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v1220; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v1526; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v1499; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v1263; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v1264; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v1265; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v1266; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v1267; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v1274; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v1275; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v1276; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v1277; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v1278; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v1381; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v1384; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v1385; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v1461; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v1431; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v1208; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v1514; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v1515; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v1572; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v1365; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v1609; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v1484; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v1280; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = v1258; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = v1259; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means70.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam70, replace;cd "$startdir/$inputdata";

use 71fam, clear;

capture gen year=1900+71;

/* Steve variables */

capture drop temp; gen temp = v1802; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v1803; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v1814; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v1868; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v1876; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v1886; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v1918; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v2226; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v1908; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v2318; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v2319; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v2320; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v1839; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v1849; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v1897; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v1899; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v1984; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v2074; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = .; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v2197; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v2202; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v2303; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v1945; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v2331; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v2334; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v2336; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v1804; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v1806; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v1809; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v1823; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v2223; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v1824; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v1825; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v1826; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v1827; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v1828; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v2221; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v1829; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v1830; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v1831; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v1832; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v1834; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v1835; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v1890; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v1891; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v1896; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v1892; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v1893; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v1894; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v1895; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v1898; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v2229; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v1900; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v1901; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v1902; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v1903; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v1904; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v1905; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v1907; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v1906; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v2230; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v1908; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v1911; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v1912; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v1913; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v1914; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v1915; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v1916; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v1919; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v1920; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v1921; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v1922; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v2238; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v2319; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v2211; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v1966; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v1967; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v1968; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v1971; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v1972; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v1979; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v1980; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v1981; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v1982; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v1983; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v2093; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v2096; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v2097; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v2165; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v2187; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v1910; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v2226; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v2227; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v2284; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v2072; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v2321; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v2196; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v1986; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = v1961; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = v1962; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means71.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam71, replace;cd "$startdir/$inputdata";

use 72fam, clear;

capture gen year=1900+72;

/* Steve variables */

capture drop temp; gen temp = v2402; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v2403; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v2415; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v2468; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v2476; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v2480; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v2519; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v2852; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v2509; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v2541; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v2542; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v2544; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v2439; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v2449; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v2498; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v2500; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v2582; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v2672; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v2687; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v2823; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v2828; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v2930; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v2545; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v2960; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v2963; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v2965; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v2404; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v2407; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v2410; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v2423; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v2849; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v2424; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v2425; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v2426; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v2427; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v2428; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v2846; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v2429; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v2430; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v2431; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v2432; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v2434; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v2435; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v2491; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v2492; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v2497; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v2493; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v2494; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v2495; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v2496; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v2499; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v2855; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v2501; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v2502; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v2503; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v2504; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v2505; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v2506; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v2508; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v2507; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v2856; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v2509; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v2512; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v2513; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v2514; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v2515; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v2516; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v2517; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v2520; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v2521; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v2522; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v2523; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v2864; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v2934; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v2837; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v2565; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v2566; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v2567; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v2570; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v2571; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v2577; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v2578; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v2579; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v2580; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v2581; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v2694; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v2702; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v2703; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v2791; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v2813; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v2511; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v2852; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v2853; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v2911; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v2670; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v2968; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v2822; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v2584; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = v2561; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = v2562; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means72.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam72, replace;cd "$startdir/$inputdata";

use 73fam, clear;

capture gen year=1900+73;

/* Steve variables */

capture drop temp; gen temp = v3002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v3003; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v3015; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v3017; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = .; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = .; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v3072; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v3256; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v3062; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v3094; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v3095; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v3097; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v3027; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v3035; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v3051; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v3053; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v3115; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v3183; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v3216; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v3241; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v3300; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v3295; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v3098; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v3304; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v3307; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v3309; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v3004; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v3007; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v3010; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v3021; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v3255; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v3022; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v3254; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v3023; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v3024; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v3025; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v3026; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v3044; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v3045; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v3050; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v3046; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v3047; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v3048; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v3049; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v3052; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v3259; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v3054; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v3055; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v3056; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v3057; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v3058; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v3059; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v3061; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v3060; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v3260; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v3062; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v3065; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v3066; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v3067; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v3068; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v3069; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v3070; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v3073; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v3074; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v3075; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v3076; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v3268; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v3298; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v3107; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v3108; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v3109; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v3110; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v3111; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v3112; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v3113; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v3114; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v3206; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v3209; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v3210; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v3217; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v3231; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v3064; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v3256; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v3257; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v3279; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v3181; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v3301; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v3240; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v3117; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means73.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam73, replace;cd "$startdir/$inputdata";

use 74fam, clear;

capture gen year=1900+74;

/* Steve variables */

capture drop temp; gen temp = v3402; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v3403; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v3415; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v3437; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v3441; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v3445; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v3484; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v3676; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v3474; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v3507; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v3508; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v3510; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v3423; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v3431; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v3463; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v3465; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v3530; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v3601; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v3638; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v3663; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v3720; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v3715; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v3511; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v3724; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v3727; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v3729; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v3404; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v3407; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v3410; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v3417; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v3675; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v3418; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v3674; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v3419; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v3420; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v3421; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v3422; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v3456; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v3457; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v3462; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v3458; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v3459; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v3460; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v3461; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v3464; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v3679; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v3466; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v3467; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v3468; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v3469; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v3470; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v3471; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v3473; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v3472; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v3680; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v3474; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v3477; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v3478; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v3479; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v3480; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v3481; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v3482; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v3485; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v3486; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v3487; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v3488; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v3688; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v3718; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v3521; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v3522; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v3523; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v3524; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v3525; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v3526; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v3527; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v3528; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v3625; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v3628; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v3629; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v3639; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v3653; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v3476; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v3676; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v3677; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v3699; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v3598; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v3721; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v3662; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v3634; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v3608; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v3609; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v3532; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means74.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam74, replace;cd "$startdir/$inputdata";

use 75fam, clear;

capture gen year=1900+75;

/* Steve variables */

capture drop temp; gen temp = v3802; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v3815; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v3837; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v3841; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v3853; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v3885 + v3903; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v4154; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v3874; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v3920; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v3921; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v3923; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v3823; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v3831; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v3863; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v3865; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v3968; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v4055; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v4102; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v4093; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v4204; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v4194; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v3924; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v4225; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v4228; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v4230; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v3807; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v3810; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v3817; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v4153; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v3818; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v4152; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v3819; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v3820; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v3821; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v3822; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v3856; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v3857; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v3862; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v3858; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v3859; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v3860; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v3861; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v3864; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v4157; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v3866; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v3867; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v3868; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v3869; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v3870; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v3871; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v3873; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v3872; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v4158; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v3874; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v3877; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v3878; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v3879; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v3880; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v3881; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v3882; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v3886; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v3887; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v3888; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v3889; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v4167; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v4196; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v3938; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v3937; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v3939; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v3940; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v3941; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v3942; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v3943; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v3944; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v3945; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v3946; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v3967; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v4065; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v4074; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v4075; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v4114; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v4129; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v3876; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v4154; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v4155; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v4178; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v4207; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v4208; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v4209; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v4053; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v4224; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v4138; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v4139; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v4108; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v4109; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v3970; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means75.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam75, replace;cd "$startdir/$inputdata";

use 76fam, clear;

capture gen year=1900+76;

/* Steve variables */

capture drop temp; gen temp = v4302; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v4303; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v4315; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v4346; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v4354; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v4368; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v4399 + v4417; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v5029; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v4388; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v4435; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v4436; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v4438; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v4332; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v4344; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v5031; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v4379; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v4459; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v4605; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v4695; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v4684; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v5096; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v5070; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v4439; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v5107; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v5110; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v5112; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v4304; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v4307; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v4310; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v4318; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = v5028; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v4319; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v4320; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v4321; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v4322; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v4323; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v4325; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v4326; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v4327; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v4330; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v4331; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v4371; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v4372; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v4377; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v4373; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v4374; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v4375; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v4376; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v4378; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = v5033; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v4380; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v4381; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v4382; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v4383; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v4384; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v4385; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v4387; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v4386; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = v5034; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v4388; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v4392; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v4393; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v4394; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v4395; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v4396; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v4397; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v4401; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v4402; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v4403; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v4404; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = v5043; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v5072; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = v4743; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =.; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v4449; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v4448; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v4450; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = v4324; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v4329; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v4451; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v4452; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v4453; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v4454; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v4455; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v4456; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v4457; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v4458; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v4841; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v4611; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v4618; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v4619; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v4658; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v4693; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v4390; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v4391; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v5029; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = v5030; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v5054; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v5079; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v5080; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v5081; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v4603; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v5099; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v4681; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v4682; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v4753; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v4754; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v4461; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means76.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam76, replace;cd "$startdir/$inputdata";

use 77fam, clear;

capture gen year=1900+77;

/* Steve variables */

capture drop temp; gen temp = v5202; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v5203; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v5215; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v5254; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v5271; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v5273; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v5311 +v5330; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v5626; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v5299; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v5349; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v5350; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v5352; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v5232; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v5244; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v5627; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v5289; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v5374; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v5507; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v5567; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v5608; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v5662; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v5644; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v5353; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v5666; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v5669; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v5671; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v5204; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v5207; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v5210; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v5217; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v5218; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v5219; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v5220; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v5221; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v5222; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v5224; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v5225; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v5226; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v5229; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v5230; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v5231; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v5281; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v5282; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v5287; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v5283; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v5284; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v5285; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v5286; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v5288; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v5290; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v5291; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v5292; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v5293; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v5295; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v5296; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v5298; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v5297; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v5299; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v5303; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v5304; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v5305; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v5306; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v5307; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v5308; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v5309; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v5313; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v5314; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v5315; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v5316; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v5645; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v5502; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v5363; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v5362; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v5364; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = v5223; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v5227; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v5365; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v5366; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v5367; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v5368; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v5369; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v5370; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v5371; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = v5372; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v5373; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v5540; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v5553; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v5554; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v5578; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v5617; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v5301; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v5302; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v5626; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v5633; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v5653; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v5654; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v5655; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v5650; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v5665; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v5601; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v5602; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v5572; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v5573; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v5376; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means77.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam77, replace;cd "$startdir/$inputdata";

use 78fam, clear;

capture gen year=1900+78;

/* Steve variables */

capture drop temp; gen temp = v5702; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v5703; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v5715; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v5755; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v5770; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v5772; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v5811 + v5830; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v6173; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v5798; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v5849; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v5850; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v5852; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v5731; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v5743; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v6174; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v5788; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v5873; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v6039; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v6116; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v6157; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v6209; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v6191; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v5853; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v6213; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v6216; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v6218; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v5704; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v5707; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v5710; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v5717; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v5718; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v5719; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v5720; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v5721; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v5722; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v5723; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v5724; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v5727; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v5728; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v5729; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v5730; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v5780; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v5781; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v5786; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v5782; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v5783; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v5784; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v5785; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v5787; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v5789; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v5790; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v5791; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v5792; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v5794; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v5795; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v5797; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v5796; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v5798; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v5802; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v5803; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v5805; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v5806; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v5807; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v5808; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v5809; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v5812; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v5813; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v5814; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v5815; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v6192; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v6034; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v5863; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v5862; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v5864; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v5725; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v5865; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v5866; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v5867; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v5868; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v5869; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v5870; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v5871; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v5872; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = .; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v6003; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v6075; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v6095; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v6096; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v6127; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v5800; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v5801; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v6173; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v6180; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v6200; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v6201; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v6202; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v6197; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v6212; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v6150; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v6151; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v6121; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v6122; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v5875; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means78.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam78, replace;cd "$startdir/$inputdata";

use 79fam, clear;

capture gen year=1900+79;

/* Steve variables */

capture drop temp; gen temp = v6302; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v6303; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v6315; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v6361; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v6376; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v6378; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v6422 + v6440; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v6766; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v6409; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v6461; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v6462; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v6464; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v6336; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v6348; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v6767; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v6398; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v6497; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v6596; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v6713; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v6754; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v6802; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v6784; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v6465; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v6806; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v6809; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v6811; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v6304; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v6307; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v6310; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v6319; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v6320; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v6321; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v6322; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v6323; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v6324; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v6325; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v6326; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v6327; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v6330; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v6331; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v6332; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v6333; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v6389; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v6390; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v6396; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v6391; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v6392; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v6393; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v6394; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v6395; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v6397; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v6399; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v6400; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v6401; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v6402; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v6403; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v6404; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v6406; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v6407; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v6408; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v6409; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v6413; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v6414; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v6416; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v6417; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v6418; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v6419; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v6420; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v6423; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v6424; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v6425; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v6426; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v6785; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v6659; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v6478; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v6477; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v6479; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v6480; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v6481; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v6482; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v6483; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v6484; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v6485; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v6486; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v6487; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v6488; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v6489; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v6492; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v6591; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v6576; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v6678; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v6679; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v6688; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v6689; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v6724; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v6763; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v6411; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v6412; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v6766; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v6773; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v6793; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v6794; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v6795; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v6790; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v6805; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v6747; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v6748; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v6718; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v6719; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v6493; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v6729; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means79.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam79, replace;cd "$startdir/$inputdata";

use 80fam, clear;

capture gen year=1900+80;

/* Steve variables */

capture drop temp; gen temp = v6902; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v6903; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v6915; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v6959; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v6972; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v6974; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v7012 + v7044; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v7412; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v6999; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v7066; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v7067; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v7069; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v6934; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v6946; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v7413; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v6988; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v7100; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v7198; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v7346; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v7387; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v7447; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v7430; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v7070; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v7452; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v7453; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v7454; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v6904; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v6907; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v6910; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v6917; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v6918; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v6919; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v6920; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v6921; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v6922; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v6923; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v6924; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v6925; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v6926; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v6929; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v6930; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v6931; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v6932; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v6933; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v6979; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v6980; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v6986; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v6981; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v6982; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v6983; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v6984; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v6985; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v6987; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v6989; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v6990; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v6991; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v6992; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v6993; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v6994; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v6996; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v6997; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v6998; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v6999; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v7001; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v7002; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v7003; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v7004; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v7006; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v7007; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v7008; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v7009; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v7010; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v7013; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v7014; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v7015; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v7016; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v7431; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v7261; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v7081; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v7080; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v7082; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v7083; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v7084; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v7085; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v7086; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v7087; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v7088; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v7089; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v7090; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v7091; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v7092; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v7093; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v7094; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v7095; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v7193; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v7178; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v7275; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v7276; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v7291; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v7292; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v7357; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v7396; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v7399; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v7400; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v7412; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v7419; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v7438; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v7439; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v7440; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v7435; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v7451; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v7380; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v7381; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v7351; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v7352; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v7096; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v7362; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means80.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam80, replace;cd "$startdir/$inputdata";

use 81fam, clear;

capture gen year=1900+81;

/* Steve variables */

capture drop temp; gen temp = v7502; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v7503; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v7515; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v7551; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v7564; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v7566; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v7604 + v7636; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v8065; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v7591; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v7657; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v7658; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v7660; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v7530; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v7540; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v8066; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v7580; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v7712; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v7885; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v7998; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v8039; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v8099; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v8082; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v7661; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v8104; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v8105; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v8106; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v7504; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v7507; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v7510; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v7517; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v7518; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v7519; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v7520; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v7521; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v7522; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v7523; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v7524; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v7525; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v7526; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v7527; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v7528; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v7699; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v7529; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v7571; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v7572; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v7578; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v7573; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v7574; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v7575; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v7576; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v7577; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v7579; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v7581; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v7582; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v7583; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v7584; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v7585; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v7586; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v7588; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v7589; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v7590; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v7591; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v7593; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v7594; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v7595; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v7596; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v7598; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v7599; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v7600; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v7601; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v7602; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v7605; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v7606; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v7607; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v7608; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v8083; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v7952; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v7672; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v7671; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v7673; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v7674; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v7675; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v7676; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v7677; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v7678; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v7679; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v7680; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v7700; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v7701; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v7702; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v7703; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v7704; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v7705; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v7706; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v7879; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v7864; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v7967; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v7968; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v7991; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v7992; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v8009; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v8048; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v8052; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v8053; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v8065; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v8071; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v8090; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v8091; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v8092; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v8087; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v8103; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v8032; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v8033; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v8003; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v8004; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v7707; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v8014; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means81.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam81, replace;cd "$startdir/$inputdata";

use 82fam, clear;

capture gen year=1900+82;

/* Steve variables */

capture drop temp; gen temp = v8202; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v8203; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v8215; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v8249; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v8256; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v8258; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v8297 + v8329; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v8689; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v8284; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v8351; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v8352; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v8354; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v8228; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v8238; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v8690; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v8273; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v8380; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v8544; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v8622; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v8663; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v8723; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v8706; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v8355; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v8728; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v8729; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v8730; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v8204; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v8207; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v8210; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v8217; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v8218; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v8219; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v8220; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v8221; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v8222; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v8223; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v8224; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v8225; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v8226; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v8227; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v8263; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v8264; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v8270; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v8265; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v8266; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v8267; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v8268; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v8269; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v8271; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v8274; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v8275; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v8276; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v8277; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v8278; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v8279; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v8281; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v8282; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v8283; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v8284; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v8286; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v8287; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v8288; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v8289; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v8291; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v8292; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v8293; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v8294; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v8295; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v8298; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v8299; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v8300; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v8301; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v8707; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v8603; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v8360; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v8362; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v8363; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v8364; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v8367; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = v8368; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v8369; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v8370; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v8371; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v8372; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v8373; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v8374; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v8538; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v8524; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v8606; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v8607; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v8610; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v8611; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v8633; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v8672; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v8676; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v8677; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v8689; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v8695; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v8714; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v8715; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v8716; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v8711; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v8727; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v8656; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v8657; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v8627; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v8628; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v8375; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v8638; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means82.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam82, replace;cd "$startdir/$inputdata";

use 83fam, clear;

capture gen year=1900+83;

/* Steve variables */

capture drop temp; gen temp = v8802; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v8803; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v8815; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v8851; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v8864; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v8866; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v8905 + v8937; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v9375; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v8892; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v8960; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v8961; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v8963; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v8830; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v8840; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v9376; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v8881; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v9011; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v9194; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v9396; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v9349; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v9408; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v9392; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v8964; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v9415; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v9416; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v9417; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v8804; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v8807; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v8810; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v8817; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v8818; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v8819; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v8820; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v8821; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v8822; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v8823; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v8824; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v8825; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v8826; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v8827; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v8828; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v8998; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v8829; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v8871; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v8872; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v8878; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v8873; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v8874; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v8875; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v8876; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v8877; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v8879; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v8882; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v8883; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v8884; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v8885; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v8886; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v8887; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v8889; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v8890; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v8891; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v8892; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v8894; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v8895; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v8896; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v8897; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v8899; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v8900; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v8901; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v8902; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v8903; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v8906; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v8907; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v8908; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v8909; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v9393; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v9276; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v8970; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v8969; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v8971; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v8972; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v8973; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v8974; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v8975; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v8976; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v8977; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v8978; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v8979; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v8999; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v9000; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v9001; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v9002; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v9003; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v9004; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v9005; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v9188; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v9174; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v9286; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v9287; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v9301; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v9302; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v9319; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v9358; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v9362; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v9363; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v9375; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v9381; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v9399; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v9400; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v9401; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v9419; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v9422; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v9423; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v9433; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v9342; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v9343; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v9313; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v9314; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v9006; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v9324; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means83.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam83, replace;cd "$startdir/$inputdata";

use 84fam, clear;

capture gen year=1900+84;

/* Steve variables */

capture drop temp; gen temp = v10002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v10003; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v10015; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v10222; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v10235; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v10237; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v10300 + v10394; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v11022; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v10278; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v10418; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v10419; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v10421; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v10037; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v10131; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v11023; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v10263; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v10460; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v10678; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v10955; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v10996; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v11055; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v11039; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v10422; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v11061; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v11062; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v11063; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v10004; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v10007; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v10010; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v10018; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v10019; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v10020; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v10021; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v10022; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v10023; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v10024; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v10025; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v10026; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v10027; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v10028; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v10029; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v10030; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v10031; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v10032; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v10254; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v10255; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v10261; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v10256; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v10257; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v10258; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v10259; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v10260; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v10262; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v10264; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v10265; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v10266; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v10267; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v10268; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v10269; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v10270; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v10272; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v10275; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v10276; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v10277; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v10278; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v10280; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v10281; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v10282; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v10283; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v10286; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v10288; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v10291; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v10293; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v10295; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v10296; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v10302; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v10303; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v10304; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v10305; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v11040; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v10424; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v10426; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v10433; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v10432; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v10434; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v10435; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v10436; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v10437; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v10438; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v10439; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v10440; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v10445; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v10447; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v10448; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v10449; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v10450; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v10451; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v10452; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v10453; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v10671; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v10657; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v10870; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v10871; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v10892; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v10893; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v10876; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v10966; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v11005; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v11009; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v11010; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v11022; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v11028; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v11046; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v11047; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v11048; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v11065; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v11068; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v11069; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v11079; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v10989; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v10990; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v10960; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v10961; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v10456; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v10971; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means84.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam84, replace;cd "$startdir/$inputdata";

use 85fam, clear;

capture gen year=1900+85;

/* Steve variables */

capture drop temp; gen temp = v11102; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v11103; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v11117; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v11364; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v11375; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v11377; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v11445 + v11457 +v11574; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v12371; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v11420; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v11605; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v11606; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v11608; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v11146; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v11258; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v12372; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v11404; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v11651; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v12014; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v12401; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v12400; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v11938; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v12397; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v11609; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v12422; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v12423; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v12424; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v11104; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v11107; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v11112; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v11120; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v11121; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v11122; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v11125; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v11126; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v11127; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v11128; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v11129; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v11130; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v11131; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v11132; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v11133; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v11134; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v11135; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v11136; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v11137; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v11138; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v11139; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v11394; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v11395; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v11396; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v11402; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v11397; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v11398; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v11399; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v11400; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v11401; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v11403; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v11405; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v11406; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v11407; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v11408; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v11409; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v11411; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v11412; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v11414; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v11417; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v11418; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v11419; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v11420; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v11424; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v11425; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v11426; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v11427; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v11428; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v11431; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v11433; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v11436; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v11438; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v11440; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v11441; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v11447; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v11449; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v11451; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v11452; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v11453; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v11459; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v11457; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v11460; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v11461; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = v12398; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v11611; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v11612; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v11613; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v11614; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v11615; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v11616; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v11617; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v11618; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v11619; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v11620; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v11621; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v11626; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v11628; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v11629; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v11630; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v11631; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v11632; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v11633; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v11637; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v12000; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v11638; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v11886; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v11887; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v11893; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v11894; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v11895; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v12292; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v12293; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v11906; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v11937; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v11981; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v12358; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v12359; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v12371; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v12379; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v12380; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v12381; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v12382; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v12404; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v12405; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v12406; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v12426; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v12429; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v12430; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v12446; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v11922; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v11923; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v12277; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v12278; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v11640; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v11911; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means85.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam85, replace;cd "$startdir/$inputdata";

use 86fam, clear;

capture gen year=1900+86;

/* Steve variables */

capture drop temp; gen temp = v12502; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v12503; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v12515; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v12763; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v12774; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v12776; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v12844 + v12864 + v12891; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v13623; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v12819; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v13010; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v13011; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v13013; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v12545; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v12657; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v13624; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v12803; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v13054; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v13233; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v13641; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v13640; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v13565; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v13010 - v13014; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v13014; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v13662; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v13663; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v13664; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v12504; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v12507; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v12510; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v12519; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v12520; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v12521; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v12524; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v12525; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v12526; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v12527; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v12528; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v12529; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v12530; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v12531; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v12532; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v12533; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v12534; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v12535; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v12536; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v12537; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v12538; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v12793; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v12794; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v12795; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v12801; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v12796; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v12797; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v12798; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v12799; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v12800; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v12802; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v12804; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v12805; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v12806; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v12807; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v12808; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v12810; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v12811; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v12813; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v12816; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v12817; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v12818; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v12819; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v12823; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v12824; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v12825; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v12826; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v12827; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v12830; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v12832; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v12835; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v12837; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v12839; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v12840; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v12846; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v12847; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v12848; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v12851; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v12853; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v12856; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v12858; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v12859; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v12860; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v12866; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v12850; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v12864; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v12867; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v12868; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v13016; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v13017; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v13018; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v13019; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v13020; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v13021; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v13022; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v13023; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v13024; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v13025; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v13026; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v13029; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v13030; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v13033; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v13034; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v13035; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v13037; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v13038; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v13039; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v13040; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v13041; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v13042; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v13046; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v13225; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v13047; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v13397; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v13398; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v13404; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v13405; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v13406; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v13499; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v13500; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v13533; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v13564; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v13604; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v13610; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v13611; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v13623; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v13631; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v13632; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v13633; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v13634; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v13644; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v13645; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v13646; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v13665; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v13668; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v13669; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v13687; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v13549; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v13550; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v13485; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v13486; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v13049; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v13538; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means86.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam86, replace;cd "$startdir/$inputdata";

use 87fam, clear;

capture gen year=1900+87;

/* Steve variables */

capture drop temp; gen temp = v13702; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v13703; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v13715; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v13867; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v13876; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v13878; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v13946 + v13966 + v14083; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v14670; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v13921; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v14113; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v14114; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v14116; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v13745; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v13809; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v14671; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v13905; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v14154; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v14329; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v14688; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v14687; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v14612; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v14113 - v14117; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v14117; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v14709; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v14710; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v14711; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v13704; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v13707; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v13710; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v13719; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v13720; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v13721; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v13724; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v13725; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v13726; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v13727; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v13728; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v13729; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v13730; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v13731; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v13732; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v13733; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v13734; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v13735; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = v13736; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = v13737; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v13738; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v13895; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v13896; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v13897; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v13903; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v13898; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v13899; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v13900; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v13901; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v13902; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v13904; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v13906; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v13907; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v13908; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v13909; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v13910; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v13912; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v13913; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v13915; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v13918; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v13919; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v13920; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v13921; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v13925; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v13926; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v13927; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v13928; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v13929; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v13932; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v13934; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v13937; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v13939; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v13941; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v13942; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v13948; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v13949; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v13950; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v13953; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v13955; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v13958; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v13960; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v13961; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v13962; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v13968; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v13952; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v13966; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v13969; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v13970; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v14119; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v14120; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v14121; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v14122; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v14123; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v14124; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v14125; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v14126; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = v14130; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v14127; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v14128; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v14129; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v14131; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v14132; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v14133; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v14136; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v14137; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v14138; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = v14139; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v14140; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v14141; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v14142; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v14143; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v14144; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v14145; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v14146; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v14321; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v14147; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v14494; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v14495; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v14501; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v14502; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v14503; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v14546; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v14547; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v14580; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v14611; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v14651; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v14657; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v14658; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v14670; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v14678; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v14679; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v14680; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v14684; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v14691; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v14692; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v14693; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v14712; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v14715; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v14716; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v14737; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v14596; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v14597; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v14532; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v14533; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v14149; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v14586; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means87.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam87, replace;cd "$startdir/$inputdata";

use 88fam, clear;

capture gen year=1900+88;

/* Steve variables */

capture drop temp; gen temp = v14802; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v14803; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v14815; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v14889; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = .; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = .; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v14961 + v14981 + v15098; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v16144; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v14936; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v15129; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v15130; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v15132; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v14835; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v14865; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v16145; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v14920; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v15162; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v15464; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v16162; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v16161; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v16086; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v15129 - v15133; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v15133; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v16183; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v16184; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v16185; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v14804; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v14807; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v14810; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v14819; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v14820; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v14821; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v14824; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v14825; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v14826; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v14827; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v14828; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v14910; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v14911; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v14912; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v14918; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v14913; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v14914; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v14915; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v14916; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v14917; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v14919; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v14921; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v14922; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v14923; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v14924; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v14925; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v14927; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v14928; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v14930; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v14933; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v14934; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v14935; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v14936; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v14940; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v14941; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v14942; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v14943; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v14944; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v14947; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v14949; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v14952; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v14954; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v14956; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v14957; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v14963; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v14964; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v14965; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v14968; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v14970; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v14973; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v14975; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v14976; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v14977; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v14983; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v14967; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v14981; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v14984; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v14985; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v15135; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v15136; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v15137; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v15138; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v15139; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v15140; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v15141; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v15142; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v15143; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v15144; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v15145; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v15146; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v15147; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v15148; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v15149; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v15150; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v15151; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v15152; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v15153; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v15154; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v15456; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v15155; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v15762; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v15763; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v15769; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v15770; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v15772; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = v15774; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v16020; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v16021; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v16054; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v16085; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v16125; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v16131; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v16132; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v16144; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v16152; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v16153; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v16154; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v16155; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v16165; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v16166; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v16167; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v16187; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v16190; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v16191; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v16208; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v16070; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v16071; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v16006; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v16007; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v15157; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v16059; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means88.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam88, replace;cd "$startdir/$inputdata";

use 89fam, clear;

capture gen year=1900+89;

/* Steve variables */

capture drop temp; gen temp = v16302; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v16303; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v16315; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v16389; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = .; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = .; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v16461 + v16481 + 16598; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v17533; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v16436; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v16630; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v16631; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v16633; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v16335; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v16365; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v17534; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v16420; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v16663; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v16982; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v17546; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v17545; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v17483; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v16630 - v16634; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v16634; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = v17561; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = v17562; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v17563; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v16304; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v16307; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v16310; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v16319; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v16320; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v16321; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v16324; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v16325; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v16326; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v16327; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v16328; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v16410; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v16411; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v16412; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v16418; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v16413; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v16414; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v16415; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v16416; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v16417; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v16419; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v16421; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v16422; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v16423; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v16424; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v16425; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v16427; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v16428; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v16430; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v16433; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v16434; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v16435; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v16436; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v16440; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v16441; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v16442; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v16443; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v16444; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v16447; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v16449; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v16452; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v16454; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v16456; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v16457; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v16463; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v16464; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v16465; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v16468; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v16470; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v16473; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v16475; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v16476; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v16477; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v16483; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v16466; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v16481; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v16484; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v16485; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v16636; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v16637; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v16638; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v16639; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v16640; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v16641; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v16642; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v16643; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v16644; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v16645; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v16646; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v16647; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v16648; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v16649; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v16650; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v16651; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v16652; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v16653; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v16654; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v16655; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v16974; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v16656; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v17297; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v17298; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v17304; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v17305; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v17307; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v17417; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v17418; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v17451; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v17482; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v17522; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v17528; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v17529; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v17533; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v17538; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v17539; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v17540; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v17541; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v17547; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v17548; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v17549; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v17565; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v17568; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v17569; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v17612; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v17467; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v17468; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v17403; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v17404; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v16658; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v17456; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means89.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam89, replace;cd "$startdir/$inputdata";

use 90fam, clear;

capture gen year=1900+90;

/* Steve variables */

capture drop temp; gen temp = v17702; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v17703; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v17715; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v17798; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v17807; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v17809; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v17877 + v17897 + v18014; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v18875; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v17852; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v18048; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v18049; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v18051; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v17744; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v17774; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v18878; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v17836; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v18101; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v18403; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v18899; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v18898; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v18814; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v18048 - v18052; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v18052; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v18915; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v17704; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v17707; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v17710; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v17719; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v17720; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v17721; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v17724; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v17725; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v17726; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v17727; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v17728; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v17729; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v17730; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v17731; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = v17732; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v17733; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v17734; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v17735; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v17736; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v17737; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v17826; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v17827; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v17828; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v17834; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v17829; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v17830; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v17831; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v17832; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v17833; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v17835; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v17837; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v17838; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v17839; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v17840; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v17841; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v17843; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v17844; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v17846; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v17849; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v17850; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v17851; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v17852; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = v17855; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v17856; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v17857; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v17858; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v17859; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v17860; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v17863; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v17865; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v17868; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v17870; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v17872; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v17873; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v17879; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v17880; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v17881; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v17884; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v17886; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v17889; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v17891; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v17892; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v17893; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v17899; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v17883; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v17897; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v17900; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v17901; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v18054; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v18055; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v18056; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v18070; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v18068; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v18069; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v18071; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v18072; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = v18076; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v18073; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v18074; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v18075; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = v18077; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v18078; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v18080; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v18081; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = v18079; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v18082; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v18083; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v18084; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v18087; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v18088; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v18089; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v18090; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v18091; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v18092; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v18093; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v18395; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v18094; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v18701; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v18702; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v18708; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v18709; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = v18710; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v18711; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v18748; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v18749; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v18782; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v18813; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v18853; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v18862; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v18863; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v18875; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v18889; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v18890; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v18891; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v18895; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v18901; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v18902; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v18903; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v18916; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v18919; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v18920; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v18943; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = v18945; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v18798; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v18799; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v18734; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v18735; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v18096; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v18787; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means90.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam90, replace;cd "$startdir/$inputdata";

use 91fam, clear;

capture gen year=1900+91;

/* Steve variables */

capture drop temp; gen temp = v19002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v19003; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v19015; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v19098; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v19107; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v19109; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v19177 + v19197 + v19194; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v20175; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v19152; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v19348; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v19349; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v19351; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v19044; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v19074; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v20178; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v19136; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v19401; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v19703; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v20199; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v20198; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v20114; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v19348 - v19352; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v19352; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v20215; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v19004; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v19007; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v19010; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v19019; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v19020; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v19021; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v19024; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v19025; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v19026; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v19027; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v19028; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v19029; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v19030; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v19031; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = v19032; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v19033; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v19034; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v19035; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v19036; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v19037; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v19126; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v19127; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v19128; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v19134; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v19129; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v19130; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v19131; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v19132; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v19133; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v19135; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v19137; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v19138; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v19139; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v19140; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v19141; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v19143; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v19144; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v19146; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v19149; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v19150; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v19151; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v19152; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = v19155; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v19156; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v19157; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v19158; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v19159; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v19160; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v19163; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v19165; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v19168; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v19170; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v19172; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v19173; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v19179; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v19180; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v19181; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v19184; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v19186; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v19189; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v19191; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v19192; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v19193; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v19199; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v19183; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v19197; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v19200; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v19201; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v19354; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v19355; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v19356; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v19370; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v19368; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v19369; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v19371; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v19372; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = v19376; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v19373; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v19374; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v19375; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = v19377; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v19378; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v19380; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v19381; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = v19379; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v19382; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v19383; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v19384; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v19387; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v19388; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v19389; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v19390; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v19391; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v19392; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v19393; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v19695; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v19394; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v20001; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v20002; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v20008; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v20009; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = v20010; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v20011; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v20048; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v20049; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v20082; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v20113; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v20153; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = v20162; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = v20163; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v20175; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v20189; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v20190; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v20191; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v20195; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v20201; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v20202; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v20203; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v20216; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v20219; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v20220; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v20243; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = v20245; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v20098; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v20099; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v20034; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v20035; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v19396; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v20087; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means91.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam91, replace;cd "$startdir/$inputdata";

use 92fam, clear;

capture gen year=1900+92;

/* Steve variables */

capture drop temp; gen temp = v20302; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v20303; rename temp state; label var state /*state*/;
capture drop temp; gen temp = v20315; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = v20398; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v20407; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v20409; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v20477 + v20497 + v20614; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v21481; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v21312; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v20650; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v20651; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v20653; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v20344; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v20374; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v21484; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v20436; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v20701; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v21003; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v21505; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v21504; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v21420; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v20650 - v20654; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v20654; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v21521; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = v20304; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v20307; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = v20310; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = v20319; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = v20320; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = v20321; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = v20324; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = v20325; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = v20326; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = v20327; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = v20328; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = v20329; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = v20330; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = v20331; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = v20332; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = v20333; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = v20334; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = v20335; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = v20336; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = v20337; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = v20426; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = v20427; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = v20428; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = v20434; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = v20429; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = v20430; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = v20431; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = v20432; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = v20433; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = v20435; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = v20437; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = v20438; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = v20439; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = v20440; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = v20441; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = v20443; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = v20444; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = v20446; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = v20449; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = v20450; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = v20451; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = v20452; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = v20455; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = v20456; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = v20457; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = v20458; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = v20459; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = v20460; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = v20463; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = v20465; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = v20468; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = v20470; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = v20472; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = v20473; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = v20479; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = v20480; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = v20481; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = v20484; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = v20486; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = v20489; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = v20491; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =v20492; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = v20493; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = v20499; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = v20483; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = v20497; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = v20500; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = v20501; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = v20656; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v20657; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = v20658; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = v20670; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = v20668; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = v20669; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = v20671; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = v20672; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = v20676; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = v20673; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = v20674; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = v20675; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = v20677; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = v20678; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = v20680; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = v20681; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = v20679; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = v20682; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = v20683; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = v20684; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = v20687; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = v20688; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = v20689; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = v20690; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = v20691; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = v20692; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v20693; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v20995; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = v20694; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = v21301; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = v21302; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = v21308; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = v21309; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = v21310; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = v21311; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = v21354; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = v21355; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = v21388; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = v21419; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = v21459; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = v21481; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = v21495; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = v21496; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = v21497; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = v21501; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = v21507; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = v21508; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = v21509; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v21522; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = v21525; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = v21526; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v21547; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = v21549; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v21404; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v21405; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v21340; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v21341; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v20696; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v21393; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means92.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam92, replace;cd "$startdir/$inputdata";

use 93fam, clear;

capture gen year=1900+93;

/* Steve variables */

capture drop temp; gen temp = v21602; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = v21603; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = v21707; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = v21711; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = v22156 + v22333  + v22392; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = v23322; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = v21960; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = v22405; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = v22406; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = v22408; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = v21634; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = v21670; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = v23323; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = v23324; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = v22456; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = v22809; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = v23334; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = v23333; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = v23276; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = v22405 - v22409; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = v22409; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = v23335; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = v21606; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =v22412; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = v22448; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = v22801; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = v23336; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = v23361; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = v23363; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = v23260; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = v23261; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = v23197; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = v23198; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = v22451; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = v23250; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=.; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= .; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= .; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= .; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= .; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= .; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= .; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=.; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=.; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= .; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= .; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= .; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= .; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= .; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= .; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= .; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= .; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= .; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= .; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= .; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= .; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means93.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam93, replace;cd "$startdir/$inputdata";

use 94fam, clear;

capture gen year=1900+94;

/* Steve variables */

capture drop temp; gen temp = er2002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er3085; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er3090; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = er3431 + er3659; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = .; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er2006; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er2007; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er2009; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = hdtot94; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = wftot94; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = .; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = .; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = upedu94w; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = upedu94h; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er3944; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er2006-er2010; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er2010; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er2014; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er2068; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er2562; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = .; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = fcwt94; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = er2074; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=hdearn94; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= wfearn94; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= hdbusy94; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= wfbusy94; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= faminc94; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= hdwks94; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= wfwks94; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=hdavg94; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=wfavg94; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= hdovt94; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= wfovt94; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= hdxtr94; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= wfxtr94; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= hdwge94; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= wfwge94; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= hdilo94; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= wfilo94; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= hdils94; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= wfils94; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= hdvac94; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= wfvac94; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= hdstr94; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= wfstr94; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= hdump94; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= wfump94; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= hdolf94; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= wfolf94; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=hdocc94; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=wfocc94; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means94.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam94, replace;cd "$startdir/$inputdata";

use 95fam, clear;

capture gen year=1900+95;

/* Steve variables */

capture drop temp; gen temp = er5002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er6084; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er6089; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = .; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er5005; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er5006; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er5008; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = hdtot95; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = wftot95; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = .; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = .; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = upedu95w; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = upedu95h; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er6814; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er5005-er5009; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er5009; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er5013; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er5067; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er5561; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = .; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = fcwt95; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = er5073; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=hdearn95; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= wfearn95; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= hdbusy95; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= wfbusy95; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= faminc95; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= hdwks95; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= wfwks95; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=hdavg95; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=wfavg95; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= hdovt95; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= wfovt95; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= hdxtr95; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= wfxtr95; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= hdwge95; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= wfwge95; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= hdilo95; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= wfilo95; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= hdils95; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= wfils95; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= hdvac95; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= wfvac95; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= hdstr95; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= wfstr95; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= hdump95; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= wfump95; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= hdolf95; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= wfolf95; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=hdocc95; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=wfocc95; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means95.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam95, replace;cd "$startdir/$inputdata";

use 96fam, clear;

capture gen year=1900+96;

/* Steve variables */

capture drop temp; gen temp = er7002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er8181; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er8186; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = .; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er7005; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er7006; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er7008; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = hdtot96; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = wftot96; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = .; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = .; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = upedu96w; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = upedu96h; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er9060; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er7005-er7009; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er7009; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er7013; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er7163; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er7657; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = .; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = fcwt96; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = er7169; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=hdearn96; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= wfearn96; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= hdbusy96; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= wfbusy96; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= faminc96; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= hdwks96; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= wfwks96; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=hdavg96; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=wfavg96; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= hdovt96; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= wfovt96; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= hdxtr96; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= wfxtr96; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= hdwge96; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= wfwge96; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= hdilo96; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= wfilo96; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= hdils96; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= wfils96; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= hdvac96; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= wfvac96; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= hdstr96; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= wfstr96; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= hdump96; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= wfump96; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= hdolf96; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= wfolf96; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=hdocc96; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=wfocc96; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means96.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam96, replace;cd "$startdir/$inputdata";

use 97fam, clear;

capture gen year=1900+97;

/* Steve variables */

capture drop temp; gen temp = er10002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er11076; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er11081; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = er12079; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er10008; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er10009; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er10011; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = hdtot97; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = wftot97; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = .; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = .; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = upedu97w; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = upedu97h; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er11848; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er10008-er10012; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er10012; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er10016; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er10081; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er10563; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = .; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = .; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = er12084; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = er10086; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=hdearn97; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= wfearn97; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= hdbusy97; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= wfbusy97; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= faminc97; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= hdwks97; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= wfwks97; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=hdavg97; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=wfavg97; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= hdovt97; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= wfovt97; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= hdxtr97; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= wfxtr97; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= hdwge97; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= wfwge97; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= hdilo97; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= wfilo97; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= hdils97; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= wfils97; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= hdvac97; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= wfvac97; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= hdstr97; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= wfstr97; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= hdump97; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= wfump97; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= hdolf97; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= wfolf97; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=hdocc97; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=wfocc97; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means97.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam97, replace;cd "$startdir/$inputdata";

use 99fam, clear;

capture gen year=1900+99;

/* Steve variables */

capture drop temp; gen temp = er13002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er14295; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er14300; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = er16462; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er13009; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er13010; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er13012; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = hdtot99; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = wftot99; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = er13215; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = er13727; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = upedu99w; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = upedu99h; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er15928; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er13009-er13013; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er13013; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er13021; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er13205; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er13717; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = er16423; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = .; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = .; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = er13210; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=hdearn99; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= wfearn99; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= hdbusy99; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= wfbusy99; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= faminc99; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= hdwks99; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= wfwks99; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=hdavg99; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=wfavg99; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= hdovt99; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= wfovt99; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= hdxtr99; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= wfxtr99; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= hdwge99; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= wfwge99; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= hdilo99; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= wfilo99; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= hdils99; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= wfils99; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= hdvac99; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= wfvac99; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= hdstr99; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= wfstr99; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= hdump99; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= wfump99; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= hdolf99; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= wfolf99; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=hdocc99; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=wfocc99; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means99.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam99, replace;cd "$startdir/$inputdata";

use 101fam, clear;

capture gen year=1900+101;

/* Steve variables */

capture drop temp; gen temp = er17002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er18431; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er18438; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = .; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er17012; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er17013; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er17015; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = hdtot01; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = wftot01; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = er17226; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = er17796; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = upedu01w; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = upedu01h; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er19989; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er17012-er17016; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er17016; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er17024; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er17216; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er17786; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = er20369; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = .; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = er20394; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = er17221; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=hdearn01; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= wfearn01; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= hdbusy01; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= wfbusy01; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= faminc01; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= hdwks01; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= wfwks01; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=hdavg01; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=wfavg01; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= hdovt01; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= wfovt01; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= hdxtr01; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= wfxtr01; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= hdwge01; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= wfwge01; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= hdilo01; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= wfilo01; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= hdils01; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= wfils01; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= hdvac01; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= wfvac01; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= hdstr01; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= wfstr01; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= hdump01; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= wfump01; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= hdolf01; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= wfolf01; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=hdocc01; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=wfocc01; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means101.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam101, replace;cd "$startdir/$inputdata";

use 103fam, clear;

capture gen year=1900+103;

/* Steve variables */

capture drop temp; gen temp = er21002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er21696; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er21703; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = er24099; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er21016; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er21017; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er21019; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = er24080; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = er24091; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = .; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = er21401; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = er24149; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = er24148; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er23426; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er21016-er21020; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er21020; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er21023; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er21123; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er21373; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = er24150; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = .; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = er24179; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = .; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=er24116; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= er24135; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= er24109; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= er24111; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= er24099; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= er24077; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= er24088; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=er24078; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=er24089; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= er24079; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= er24090; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= er24137; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= er24138; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= er24081; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= er24092; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= er24082; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= er24093; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= er24083; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= er24094; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= er24084; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= er24095; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= er24086; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= er24097; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= er24087; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= er24098; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means103.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam103, replace;cd "$startdir/$inputdata";

use 105fam, clear;

capture gen year=1900+105;

/* Steve variables */

capture drop temp; gen temp = er25002; rename temp intnum; label var intnum /*intnum_family_file*/;
capture drop temp; gen temp = .; rename temp state; label var state /*state*/;
capture drop temp; gen temp = .; rename temp famcomp; label var famcomp /*famcomp*/;
capture drop temp; gen temp = .; rename temp famsize; label var famsize /*famsize*/;
capture drop temp; gen temp = er25698; rename temp con1; label var con1 /*Consumption 1: food expenditures*/;
capture drop temp; gen temp = er25705; rename temp con2; label var con2 /*Consumption 2: eating out*/;
capture drop temp; gen temp = .; rename temp inc1; label var inc1 /*Income 1: Transfers In*/;
capture drop temp; gen temp = er28037; rename temp inc2; label var inc2 /*Income 2: Income*/;
capture drop temp; gen temp = .; rename temp inc3; label var inc3 /*Income 3: Transfers Out*/;
capture drop temp; gen temp = er25016; rename temp numfamunit; label var numfamunit /*Number in family unit*/;
capture drop temp; gen temp = er25017; rename temp agehead; label var agehead /*Age of head*/;
capture drop temp; gen temp = er25019; rename temp agewife; label var agewife /*Age of wife*/;
capture drop temp; gen temp = er27886; rename temp Hworkhrs; label var Hworkhrs /*Husband work hours*/;
capture drop temp; gen temp = er27897; rename temp Wworkhrs; label var Wworkhrs /*Wifes work hours*/;
capture drop temp; gen temp = .; rename temp Hlaborinc; label var Hlaborinc /*Husbands labor income*/;
capture drop temp; gen temp = .; rename temp Wlaborinc; label var Wlaborinc /*Wifes labor income*/;
capture drop temp; gen temp = .; rename temp Hoccupation; label var Hoccupation /*Husbands occupation*/;
capture drop temp; gen temp = er25397; rename temp Woccupation; label var Woccupation /*Wifes occupation*/;
capture drop temp; gen temp = er28048; rename temp Weducation; label var Weducation /*Wifes education*/;
capture drop temp; gen temp = er28047; rename temp Heducation; label var Heducation /*Husbands education*/;
capture drop temp; gen temp = er27393; rename temp race; label var race /*Race*/;
capture drop temp; gen temp = er25016-er25020; rename temp numadults; label var numadults /*Number of adults*/;
capture drop temp; gen temp = er25020; rename temp numkids; label var numkids /*Number of Kids*/;
capture drop temp; gen temp = .; rename temp cntylabor; label var cntylabor /*County labor shortage/surplus*/;
capture drop temp; gen temp = .; rename temp cntywage; label var cntywage /*County typical wage*/;
capture drop temp; gen temp = .; rename temp cntyunemp; label var cntyunemp /*County unemployment rate*/;

 
/* Todd variables */

capture drop temp; gen temp = .; rename temp cntypsid; label var cntypsid /*County PSID code*/;
capture drop temp; gen temp = .; rename temp splitoffind; label var splitoffind /*Splitoff indicator*/;
capture drop temp; gen temp = .; rename temp famcompchange; label var famcompchange /*Family composition change*/;
capture drop temp; gen temp = .; rename temp hholdrage; label var hholdrage /*Age of householder*/;
capture drop temp; gen temp = .; rename temp hholdrsex; label var hholdrsex /*Gender of householder*/;
capture drop temp; gen temp = .; rename temp hholdrelfamh; label var hholdrelfamh /*Householder Relation to FU head*/;
capture drop temp; gen temp = .; rename temp hval; label var hval /*House_value*/;
capture drop temp; gen temp = .; rename temp hval2; label var hval2 /*House_value_2*/;
capture drop temp; gen temp = .; rename temp hvalacc; label var hvalacc /*House_value_Accuracy*/;
capture drop temp; gen temp = .; rename temp remmortprin; label var remmortprin /*Remaining_Mortg_Principal*/;
capture drop temp; gen temp = .; rename temp remmortprinacc; label var remmortprinacc /*Rem_Mort_Prin_Accuracy*/;
capture drop temp; gen temp = .; rename temp annmortpay; label var annmortpay /*Annual_Mortgage_Payments*/;
capture drop temp; gen temp = .; rename temp annmortpayacc; label var annmortpayacc /*Mort_Payments_Accuracy*/;
capture drop temp; gen temp = .; rename temp annproptax; label var annproptax /*Annual_Property_Taxes*/;
capture drop temp; gen temp = .; rename temp annproptaxacc; label var annproptaxacc /*Property_Tax_Accuracy*/;
capture drop temp; gen temp = .; rename temp annhomeins; label var annhomeins /*Homeowners_Insurance*/;
capture drop temp; gen temp = .; rename temp annrentpaid; label var annrentpaid /*Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annrentpaidacc; label var annrentpaidacc /*Accuracy_Annual_Rent_Paid*/;
capture drop temp; gen temp = .; rename temp annfreehousval; label var annfreehousval /*Annual_value_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annfreehousacc; label var annfreehousacc /*Accuracy_Free_Housing*/;
capture drop temp; gen temp = .; rename temp annutil; label var annutil /*Annual_Utilities*/;
capture drop temp; gen temp = .; rename temp annutilacc; label var annutilacc /*Accuracy_Utilities*/;
capture drop temp; gen temp = .; rename temp govsubhtg; label var govsubhtg /*Govt_Subsidy_of_Heating*/;
capture drop temp; gen temp = .; rename temp hwhavetaxinc; label var hwhavetaxinc /*HW_Have_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp linc1; label var linc1 /*Farm_Income_from_Labor*/;
capture drop temp; gen temp = .; rename temp linc2; label var linc2 /*Business_Income_Labor*/;
capture drop temp; gen temp = .; rename temp linc3; label var linc3 /*Roomers_Income_Labor*/;
capture drop temp; gen temp = .; rename temp hwages; label var hwages /*Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hwagesacc; label var hwagesacc /*Accuracy_Heads_Wages*/;
capture drop temp; gen temp = .; rename temp hlinc1; label var hlinc1 /*Heads_Income_from_Bonus*/;
capture drop temp; gen temp = .; rename temp hlinc2; label var hlinc2 /*Heads_Income_Prof_Practice*/;
capture drop temp; gen temp = .; rename temp hlinc3; label var hlinc3 /*Heads_Gardening_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp hlincacc; label var hlincacc /*Accuracy_Heads_Inc_Labor*/;
capture drop temp; gen temp = .; rename temp wlinc1; label var wlinc1 /*Wifes_WageLabor_Income_2*/;
capture drop temp; gen temp = .; rename temp wlincacc1; label var wlincacc1 /*Accuracy_Wifes_WL_Income*/;
capture drop temp; gen temp = .; rename temp asinc1; label var asinc1 /*Farm_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc2; label var asinc2 /*Business_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc3; label var asinc3 /*Gardening_Income_Assets*/;
capture drop temp; gen temp = .; rename temp asinc4; label var asinc4 /*Roomers_Income_Assets*/;
capture drop temp; gen temp = .; rename temp monrecvdrent; label var monrecvdrent /*Num_of_Months_Recvd_Rent*/;
capture drop temp; gen temp = .; rename temp hinc1; label var hinc1 /*Rental_Income_Head*/;
capture drop temp; gen temp = .; rename temp divintinc; label var divintinc /*DividendInterest_Income*/;
capture drop temp; gen temp = .; rename temp winc1; label var winc1 /*Other_Asset_Income_Wife*/;
capture drop temp; gen temp = .; rename temp wincacc1; label var wincacc1 /*Accuracy_Other_Asset_W*/;
capture drop temp; gen temp = .; rename temp hwtaxinc; label var hwtaxinc /*HW_Taxable_Income*/;
capture drop temp; gen temp = .; rename temp hwtaxinc2; label var hwtaxinc2 /*HW_Taxable_Income_2*/;
capture drop temp; gen temp = .; rename temp suppdnonfu; label var suppdnonfu /*Support_Pd_to_NonFU_Memb*/;
capture drop temp; gen temp = .; rename temp blindexempt; label var blindexempt /*Blindness_Exemptions*/;
capture drop temp; gen temp = .; rename temp totexempt; label var totexempt /*Total_Exemptions*/;
capture drop temp; gen temp = .; rename temp filestat; label var filestat /*Filing_Status*/;
capture drop temp; gen temp = .; rename temp hwrectransinc; label var hwrectransinc /*HW_Rcvd_Transfer_Income*/;
capture drop temp; gen temp = .; rename temp htran1; label var htran1 /*AFDC_Received_Head*/;
capture drop temp; gen temp = .; rename temp htranacc1; label var htranacc1 /*Accuracy_AFDC_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran2; label var htran2 /*Other_Welfare_Rcvd_Head*/;
capture drop temp; gen temp = .; rename temp htran3; label var htran3 /*Social_Security_Head*/;
capture drop temp; gen temp = .; rename temp htran4; label var htran4 /*vA_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran5; label var htran5 /*Other_Pension_Head*/;
capture drop temp; gen temp = .; rename temp htran6; label var htran6 /*Unemployment_Ins_Head*/;
capture drop temp; gen temp = .; rename temp htran7; label var htran7 /*Workers_Comp_Head*/;
capture drop temp; gen temp = .; rename temp htran8; label var htran8 /*Other_Transfer_Inc_Head*/;
capture drop temp; gen temp = .; rename temp wtran1; label var wtran1 /*AFDC_Wife*/;
capture drop temp; gen temp = .; rename temp wtranacc1; label var wtranacc1 /*AFDC_Accuracy_Wife*/;
capture drop temp; gen temp = .; rename temp wtran2; label var wtran2 /*Other_Welfare_Wife*/;
capture drop temp; gen temp = .; rename temp wtran3; label var wtran3 /*Social_Security_Wife*/;
capture drop temp; gen temp = .; rename temp wtran4; label var wtran4 /*vA_Pension_Wife*/;
capture drop temp; gen temp = .; rename temp wtran5; label var wtran5 /*Other_Pensions_Wife*/;
capture drop temp; gen temp =.; rename temp wtran6; label var wtran6 /*Unemployment_Ins_Wife*/;
capture drop temp; gen temp = .; rename temp wtran7; label var wtran7 /*Workers_Comp_Wife*/;
capture drop temp; gen temp = .; rename temp wtran8; label var wtran8 /*Other_Transfer_Inc_Wife*/;
capture drop temp; gen temp = .; rename temp wtran9; label var wtran9 /*SSI_Wife*/;
capture drop temp; gen temp = .; rename temp wtran10; label var wtran10 /*Help_from_Relatives_Wife*/;
capture drop temp; gen temp = .; rename temp hwtransnoafdcacc; label var hwtransnoafdcacc /*Acc_HW_Trans_Y_No_AFDC*/;
capture drop temp; gen temp = .; rename temp HWtrans; label var HWtrans /*Total_HW_Transfer_Inc*/;
capture drop temp; gen temp = .; rename temp hwtran2; label var hwtran2 /*Total_HW_Transfer_Inc_2*/;
capture drop temp; gen temp = .; rename temp hage2; label var hage2 /*Age_Head_2*/;
capture drop temp; gen temp = .; rename temp wage2; label var wage2 /*Age_Wife_2*/;
capture drop temp; gen temp = .; rename temp nonfuinfu; label var nonfuinfu /*Number_NonFU_in_FU*/;
capture drop temp; gen temp =er25023; rename temp marital2; label var marital2 /*Marital_Status_2*/;
capture drop temp; gen temp = .; rename temp dwelltype; label var dwelltype /*Dwelling_Type*/;
capture drop temp; gen temp = .; rename temp numrooms; label var numrooms /*Number_of_Rooms*/;
capture drop temp; gen temp = .; rename temp heatftyp1; label var heatftyp1 /*Type_of_Heating_Fuel_1*/;
capture drop temp; gen temp = .; rename temp heatftype2; label var heatftype2 /*Type_of_Heating_Fuel_2*/;
capture drop temp; gen temp = .; rename temp recgovhtsub; label var recgovhtsub /*Recvd_Govt_Heating_Subs*/;
capture drop temp; gen temp = .; rename temp tenure; label var tenure /*OwnRent*/;
capture drop temp; gen temp = .; rename temp mortinclptax; label var mortinclptax /*Mort_Pay_Incl_Prop_Taxes*/;
capture drop temp; gen temp = .; rename temp havemort; label var havemort /*Have_Mortgage*/;
capture drop temp; gen temp = .; rename temp yearsmort; label var yearsmort /*Years_Left_on_Mortgage*/;
capture drop temp; gen temp = .; rename temp havemort2; label var havemort2 /*Have_2nd_Mortgage*/;
capture drop temp; gen temp = .; rename temp mortinclins; label var mortinclins /*Mort_Pay_Incl_Ins_Premium*/;
capture drop temp; gen temp = .; rename temp rentfurn; label var rentfurn /*Rented_Furnished*/;
capture drop temp; gen temp = .; rename temp publhous; label var publhous /*Public_Housing*/;
capture drop temp; gen temp = .; rename temp govpayrenpart; label var govpayrenpart /*Govt_Pay_Part_Rent*/;
capture drop temp; gen temp = .; rename temp rentinclht; label var rentinclht /*Rent_Includes_Heat*/;
capture drop temp; gen temp = .; rename temp whynotown; label var whynotown /*Why_Not_OwnRent*/;
capture drop temp; gen temp = .; rename temp inproj; label var inproj /*In_PublicOwned_Project*/;
capture drop temp; gen temp = .; rename temp govpayrenall; label var govpayrenall /*Govt_Pay_All_Rent*/;
capture drop temp; gen temp = .; rename temp payutil; label var payutil /*Pay_Utilities_Yourself*/;
capture drop temp; gen temp = .; rename temp movlastsp; label var movlastsp /*Moved_Since_Last_Spring*/;
capture drop temp; gen temp = .; rename temp monmove; label var monmove /*Month_Moved*/;
capture drop temp; gen temp = .; rename temp whymove; label var whymove /*Why_Moved*/;
capture drop temp; gen temp = .; rename temp mightmove; label var mightmove /*Might_Move_Soon*/;
capture drop temp; gen temp = .; rename temp probmove; label var probmove /*Probability_of_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove; label var whymigmove /*Why_Might_Move*/;
capture drop temp; gen temp = .; rename temp whymigmove2; label var whymigmove2 /*Why_Might_Move_2*/;
capture drop temp; gen temp = er25104; rename temp hemploy; label var hemploy /*Employment_Status_Head*/;
capture drop temp; gen temp = er25362; rename temp wemploy; label var wemploy /*Employment_Status_Wife*/;
capture drop temp; gen temp = .; rename temp hyearret; label var hyearret /*Year_Retired_Head*/;
capture drop temp; gen temp = .; rename temp hfarmer; label var hfarmer /*Head_is_a_Farmer*/;
capture drop temp; gen temp = .; rename temp farmrcpt; label var farmrcpt /*Farm_Receipts*/;
capture drop temp; gen temp = .; rename temp getlumpsum; label var getlumpsum /*Get_LumpSum_Payments*/;
capture drop temp; gen temp = .; rename temp lumpsumamt; label var lumpsumamt /*LumpSum_Payment_Amount*/;
capture drop temp; gen temp = .; rename temp inheramt; label var inheramt /*Amount_Inheritance*/;
capture drop temp; gen temp = .; rename temp itemtax; label var itemtax /*Itemized_on_Tax_Return*/;
capture drop temp; gen temp = .; rename temp networth; label var networth /*Net_Worth_Amount*/;
capture drop temp; gen temp = .; rename temp wracehisp; label var wracehisp /*RaceHispanic_Wife*/;
capture drop temp; gen temp = .; rename temp wraceoth; label var wraceoth /*RaceOther_Wife*/;
capture drop temp; gen temp = .; rename temp hnew; label var hnew /*Whether_New_Head*/;
capture drop temp; gen temp = .; rename temp hracehisp; label var hracehisp /*RaceHispanic_Head*/;
capture drop temp; gen temp = .; rename temp hrelig; label var hrelig /*Religion_Head*/;
capture drop temp; gen temp = .; rename temp hwfedtax; label var hwfedtax /*HW_Federal_Taxes*/;
capture drop temp; gen temp = .; rename temp hwmtr; label var hwmtr /*MTR_for_HW*/;
capture drop temp; gen temp = .; rename temp fmoninc; label var fmoninc /*Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp fmoninc2; label var fmoninc2 /*Family_Money_Income_2*/;
capture drop temp; gen temp = .; rename temp region; label var region /*Current_Region*/;
capture drop temp; gen temp = .; rename temp stfips; label var stfips /*FIPS_State_Code*/;
capture drop temp; gen temp = .; rename temp cyfips; label var cyfips /*FIPS_County_Code*/;
capture drop temp; gen temp = .; rename temp fmonincacc; label var fmonincacc /*Acc_Family_Money_Income*/;
capture drop temp; gen temp = .; rename temp nkids_1; label var nkids_1 /*Num_Kids_Aged_12*/;
capture drop temp; gen temp = .; rename temp nkids_2; label var nkids_2 /*Num_Kids_Aged_35*/;
capture drop temp; gen temp = .; rename temp nkids_3; label var nkids_3 /*Num_Kids_Aged_613*/;
capture drop temp; gen temp = er28049; rename temp marital; label var marital /*Marital_Status*/;
capture drop temp; gen temp = .; rename temp hnewyr; label var hnewyr /*Year_New_Head*/;
capture drop temp; gen temp = .; rename temp wnewyr; label var wnewyr /*Year_New_Wife*/;
capture drop temp; gen temp = .; rename temp fwtcore; label var fwtcore /*Core_Family_Weight*/;
capture drop temp; gen temp = er28078; rename temp fwtlatin; label var fwtlatin /*CoreLatino_Weight*/;

/* Add-on variables */


capture drop temp; gen temp = .; rename temp HDFEducation; label var HDFEducation /* HDFEducation */;
capture drop temp; gen temp = .; rename temp HDMEducation; label var HDMEducation /* HDMEducation */;
capture drop temp; gen temp = .; rename temp WFFEducation; label var WFFEducation /* WFFEducation */;
capture drop temp; gen temp = .; rename temp WFMEducation; label var WFMEducation /* WFMEducation */;
capture drop temp; gen temp = .; rename temp WhenMovedIn; label var WhenMovedIn /* WhenMovedIn */;
capture drop temp; gen temp = .; rename temp HDselfemployed; label var HDselfemployed /* HDselfemployed */;
capture drop temp; gen temp = .; rename temp haveseatbelts; label var haveseatbelts /* haveseatbelts */;
capture drop temp; gen temp = .; rename temp useseatbelts; label var useseatbelts /* useseatbelts */;
capture drop temp; gen temp = .; rename temp HDfocc; label var HDfocc /* HDfocc */;
capture drop temp; gen temp = .; rename temp HDageofmarr; label var HDageofmarr /* HDageofmarr */;
capture drop temp; gen temp = .; rename temp HDis1stmarr; label var HDis1stmarr /* HDis1stmarr */;

/* Income, working hours and occupation variables */
capture drop temp; gen temp=er27931; rename temp HDearn; label var HDearn /*HD labor income*/;
capture drop temp; gen temp= er27943; rename temp WFearn; label var WFearn /*WF labor income*/;
capture drop temp; gen temp= er27910; rename temp HDbusi; label var HDbusi /*HD labor income from business*/;
capture drop temp; gen temp= er27940; rename temp WFbusi; label var WFbusi /*WF labor income from business*/;
capture drop temp; gen temp= er28037; rename temp inc2supp; label var inc2supp /*Family income*/;
capture drop temp; gen temp= er27883; rename temp hdwks; label var hdwks /*HD work weeks*/;
capture drop temp; gen temp= er27894; rename temp wfwks; label var wfwks /*WF work weeks*/;
capture drop temp; gen temp=er27884; rename temp hdavg; label var hdavg /*HD work hours per week*/;
capture drop temp; gen temp=er27895; rename temp wfavg; label var wfavg /*WF work hours per week*/;
capture drop temp; gen temp= er27885; rename temp hdovt; label var hdavg /*HD overtime work hours*/;
capture drop temp; gen temp= er27896; rename temp wfovt; label var wfavg /*WF overtime work hours*/;
capture drop temp; gen temp= .; rename temp hdxtr; label var hdxtr /*HD extra work hours*/;
capture drop temp; gen temp= .; rename temp wfxtr; label var wfxtr /*WF extra work hours*/;

capture drop temp; gen temp= er28003; rename temp hdwge; label var hdwge /*HD wage rate*/;
capture drop temp; gen temp= er28004; rename temp wfwge; label var wfwge /*WF wage rate*/;
capture drop temp; gen temp= er27887; rename temp hdilo; label var hdilo /*HD weeks missed for illness of others*/;
capture drop temp; gen temp= er27898; rename temp wfilo; label var wfilo /*WF weeks missed for illness of others*/;
capture drop temp; gen temp= er27888; rename temp hdils; label var hdils /*HD weeks missed for illness of self*/;
capture drop temp; gen temp= er27899; rename temp wfils; label var wfils /*WF weeks missed for illness of self*/;
capture drop temp; gen temp= er27889; rename temp hdvac; label var hdvac /*HD weeks missed for vacation*/;
capture drop temp; gen temp= er27900; rename temp wfvac; label var wfvac /*WF weeks missed for vacation*/;
capture drop temp; gen temp= er27890; rename temp hdstr; label var hdstr /*HD weeks missed for strike*/;
capture drop temp; gen temp= er27901; rename temp wfstr; label var wfstr /*WF weeks missed for strike*/;
capture drop temp; gen temp= er27892; rename temp hdump; label var hdump /*HD weeks missed for unemployment*/;
capture drop temp; gen temp= er27903; rename temp wfump; label var wfump /*WF weeks missed for unemployment */;
capture drop temp; gen temp= er27893; rename temp hdolf; label var hdolf /*HD weeks missed out of labor force*/;
capture drop temp; gen temp= er27904; rename temp wfolf; label var wfolf /*WF weeks missed out of labor force */;
capture drop temp; gen temp=.; rename temp hdocc; label var hdocc /*HD occupation 3-digit*/;
capture drop temp; gen temp=.; rename temp wfocc; label var wfocc /*WF occupation 3-digit*/;


/* drop duplicate raw variables */
capture drop v*;
capture drop er*;

/* summarize variables for consistency checks */
cd "$startdir/$logfiles";
log using means105.log, replace;

sum;

log close;

cd "$startdir/$outputdata";
save fam105, replace;


*@@@@@@@@@@@@@@@@@@;


/* END AUTOMATED CODE FROM build1merge.doc */


cd "$startdir/$outputdata";
clear;
set mem 600m;
use fam68, clear;


save fam, replace;

append using "fam69.dta";
append using "fam70.dta";
append using "fam71.dta";
append using "fam72.dta";
append using "fam73.dta";
append using "fam74.dta";
append using "fam75.dta";
append using "fam76.dta";
append using "fam77.dta";
append using "fam78.dta";
append using "fam79.dta";
append using "fam80.dta";
append using "fam81.dta";
append using "fam82.dta";
append using "fam83.dta";
append using "fam84.dta";
append using "fam85.dta";
append using "fam86.dta";
append using "fam87.dta";
append using "fam88.dta";
append using "fam89.dta";
append using "fam90.dta";
append using "fam91.dta";
append using "fam92.dta";
append using "fam93.dta";
append using "fam94.dta";
append using "fam95.dta";
append using "fam96.dta";
append using "fam97.dta";
append using "fam99.dta";
append using "fam101.dta";
append using "fam103.dta";
append using "fam105.dta";

drop *94 *95 *96 *97 *99 *01 upedu*;

save, replace;
erase "fam68.dta";
erase "fam69.dta";
erase "fam70.dta";
erase "fam71.dta";
erase "fam72.dta";
erase "fam73.dta";
erase "fam74.dta";
erase "fam75.dta";
erase "fam76.dta";
erase "fam77.dta";
erase "fam78.dta";
erase "fam79.dta";
erase "fam80.dta";
erase "fam81.dta";
erase "fam82.dta";
erase "fam83.dta";
erase "fam84.dta";
erase "fam85.dta";
erase "fam86.dta";
erase "fam87.dta";
erase "fam88.dta";
erase "fam89.dta";
erase "fam90.dta";
erase "fam91.dta";
erase "fam92.dta";
erase "fam93.dta";
erase "fam94.dta";
erase "fam95.dta";
erase "fam96.dta";
erase "fam97.dta";
erase "fam99.dta";
erase "fam101.dta";
erase "fam103.dta";
erase "fam105.dta";
